function [s3] = add(s1,s2)
%  ADD:    Add two POLPAC data structures
%
%  Usage:  s3 = add(s1,s2)
%
%  This function adds two POLPAC data structures s1 and s2.
%
%  Input Parameters:
%  -----------------
%
%    s1     := POLPAC data structure (any mode)
%    s2     := POLPAC data structure (any mode)
%
%  Output Parameters:
%  ------------------
%
%    s3     := POLPAC data structure (any mode)
%
push('ADD')
%
%  Check for mixed mode operations
%
[s1,s2] = mixmod(s1,s2);
%
%  Start by unpacking the structural information
%
[mod1,lcol1,dtyp1,styp1] = unpack(s1(1,1));
[mod2,lcol2,dtyp2,styp2] = unpack(s2(1,1));
%
%  Determine the mode classes
%
mc1 = round((mod1 + 1)/3);
mc2 = round((mod2 + 1)/3);
%
%  Check for consistency
%
if mc1 ~= mc2,
  disp('ADD: Error - Incompatible modes'),
  abort,
end
%
%  The mode classes are the same.
%  Branch according to the mode class.
%
if mc1 == 0,
  s3 = adds(s1,s2);
  else if mc1 == 1,
    s3 = addp(s1,s2);
    else if mc1 == 2,
      s3 = addg(s1,s2);
      else
        s3 = addps(s1,s2);
      end,
    end,
  end,
end
%
pull
return
