function [pnn] = aitken(sval,pval,sxx)
%  AITKEN:  POLPAC function to compute Aitken interpolation polynomial
%
%  Usage:  pnn = aitken(sval,pval,sxx)
%
%  This function computes an Aitken interpolation polynomial
%  at a set of new base values out of the knowledge of that
%  polynomial at a set of previous base values together with
%  their trajectory values.
%
%  Input Parameters:
%  -----------------
%
%    sval   := Domain base values
%    pval   := Trajectory values
%    sxx    := New domain base values
%
%  Output Paramater:
%  -----------------
%
%    pnn    := Newly calculated trajectory values
% 
push('AITKEN')
global debg
%
[r1,c1] = size(sval);
[r2,c2] = size(pval);
[r3,c3] = size(sxx);
if debg == 3,
  if r1 ~= 1,
    disp('AITKEN: Error - SVAL must be row vector'),
    abort,
  end,
  if r2 ~= 1,
    disp('AITKEN: Error - PVAL must be row vector'),
    abort,
  end,
  if r3 ~= 1,
    disp('AITKEN: Error - SXX must be row vector'),
    abort,
  end,
  if c1 ~= c2,
    disp('AITKEN: Error - SVAL, PVAL must be same length'),
    abort,
  end,
end
%
p = zeros(c3,c1);
xx = p;
for i=1:c3,
  p(i,:) = pval;
end
o = ones(r1,c1);
yy = o;
s = zeros(c3,c1);
for i=1:c3,
  s(i,:) = sval - sxx(1,i)*o;
end
for i=2:c1, 
  %
  %  for each level in evaluation matrix pxi
  %
  yy(1,i:c1) = (sval(1,i:c1) - sval(1,i-1)*o(1,i:c1));
  for k=1:c3, 
    %
    %  for each requested evaluation point sxx
    %
    xx(k,i:c1) = (s(k,i:c1)*p(k,i-1) - s(k,i-1)*p(k,i:c1)); 
    p(k,i:c1) = xx(k,i:c1) ./ yy(1,i:c1);
  end,
end
pnn = conj(p(:,c1)');
%
pull
return
