function [pm] = c07(s1)
%  C07:    POLPAC conversion state-space -> polynomial matrix system (coefs)
%
%  Usage:  pm = c07(s1)
%
%  This function converts a system description in the time domain (S1)
%  into a polynomial matrix system description (PM).  The input data
%  structure is stored in mode 0, and the output data structure is
%  stored in mode 7.
%
%  Input Parameter:
%  ----------------
%
%    s1     := System description in the time domain (mode = 0)
%
%  Output Parameter:
%  -----------------
%
%    pm     := Polynomial matrix system description (mode = 7)
%
push('C07')
%
[mode,lcol,dtype,stype] = unpack(s1(1,1));
%
[a,b,c,d] = oldsyst(s1);
[n,m] = size(a);
%
%  First, take care of the special case of a constant system
%
d = newmat(d,1,stype,0);
if n > 0,
  a = newmat(a,1,stype,0);
  b = newmat(b,1,stype,0);
  c = newmat(c,1,stype,0);
  s = [ 1 0 ];
  s = newpoly(s,stype);
  I = eyep(n,n,1,1,stype,0);
  sI = mult(s,I);
  p = sub(sI,a);
  q = b;
  r = c;
  else
  p = [];
  q = [];
  r = [];
end
w = d;
pm = c17(p,q,r,w);
%
pull
return
