function [gm] = c15(p1,p2)
%  C15:    POLPAC conversion polynomial matrices -> transfer function matrix
%
%  Usage: gm = c15(p1,p2)
%
%  This function converts two nonfactorized polynomial matrices into one
%  factorized transfer function matrix.
%
%  This mixed mode operation first converts the two input polynomial
%  matrices into their factorized form, and then conatenates them
%  into the transfer function matrix.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Nonfactorized numerator polynomial (mode = 1)
%    p2     := Nonfactorized denominator polynomial (mode = 1)
%
%  Output Parameter:
%  -----------------
%
%    gm     := Factorized transfer function matrix (mode = 5)
%
push('C15')
%
p12 = c12(p1);
p22 = c12(p2);
gm = c25(p12,p22);
%
pull
return
