function [gm] = c16(pm,qm,dom)
%  C16:    POLPAC conversion polynomial matrices -> transfer function matrix
%
%  Usage:  gm = c16(pm,qm,dom)
%
%  This function converts a numerator polynomial matrix (PM) and a
%  denominator polynomial matrix (QM) into one transfer function
%  matrix (GM).  The input data structures are dtored in mode 1, the
%  output data structure is stored in mode 6.
%
%  This is a mixed mode operation.  First, we convert PM and QM into
%  mode 3, then we concatenate them into mode 6.
%
%  Since the input data structures do not contain any DOMAIN
%  information, the DOMAIN must be user supplied.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Nonfactorized numerator polynomial (mode = 1)
%    qm     := Nonfactorized denominator polynomial (mode = 1)
%    dom    := Matlab row vector containing the domain information
%
%  Output Parameter:
%  -----------------
%
%    gm     := Trajectory transfer function matrix (mode = 6)
%
push('C16')
%
p = c13(pm,dom);
q = c13(qm,dom);
gm = c36(p,q);
%
pull
return
