function [ps] = c18(pm,qm,rm,wm)
%  C18:    POLPAC conversion polynomial matrices -> polynomial matrix system
%
%  Usage: ps = c18(pm,qm,rm,wm)
%
%  This function concatenates the four nonfactorized polynomial matrices
%  PM, QM, RM, and WM into one factorized polynomial system
%  description.
%
%  This mixed mode operation first converts each of the four polynomial
%  matrices into their factorized forms, then concatenates them to
%  their final form.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Polynomial partial state coupling matrix (mode = 1)
%    qm     := Polynomial input coupling matrix (mode = 1)
%    rm     := Polynomial output coupling matrix (mode = 1)
%    wm     := Polynomial input/output coupling matrix (mode = 1)
%
%  Output Parameter:
%  -----------------
%
%    ps     := Polynomial matrix system description (mode = 8)
%
push('C18')
%
p1 = c12(pm);
q1 = c12(qm);
r1 = c12(rm);
w1 = c12(wm);
ps = c28(p1,q1,r1,w1);
%
pull
return
