function [ps] = c19(pm,qm,rm,wm,dom)
%  C19:    POLPAC conversion polynomial matrices -> polynomial matrix system
%
%  Usage:  ps = c19(pm,qm,rm,wm,dom)
%
%  This function concatenates the four polynomial matrices P(s), Q(s),
%  R(s) and W(s) into one polynomial matrix system representation.
%
%  The input matrices are stored in storage mode 1, the output
%  matrix is stored in storage mode 9.  Thus, this is a mixed
%  mode operation.  First, all four inputs are converted from
%  mode 1 to mode 3, then they are concatenated to mode 9.
%
%  Since the input data structures do not contain the DOMAIN
%  information, this must be user supplied.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Polynomial partial state coupling matrix (mode = 1)
%    qm     := Polynomial input coupling matrix (mode = 1)
%    rm     := Polynomial output coupling matrix (mode = 1)
%    wm     := Polynomial input/output coupling matrix (mode = 1)
%    dom    := Row vector containing the domain information
%
%  Output Parameter:
%  -----------------
%
%    ps     := Polynomial system description (mode = 9)
%
push('C19')
%
p = c13(pm,dom);
q = c13(qm,dom);
r = c13(rm,dom);
w = c13(wm,dom);
ps = c39(p,q,r,w);
%
pull
return
