function [gm] = c24(p1,p2)
%  C24:    POLPAC conversion polynomial matrices -> transfer function matrix
%
%  Usage:  gm = c24(p1,p2)
%
%  This function converts two factorized polynomial matrices into one
%  nonfactorized transfer function matrix.
%
%  This mixed mode operation first converts the two input polynomial
%  matrices into their nonfactorized form, and then conatenates them
%  into the transfer function matrix.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Factorized numerator polynomial (mode = 2)
%    p2     := Factorized denominator polynomial (mode = 2)
%
%  Output Parameter:
%  -----------------
%
%    gm     := Nonfactorized transfer function matrix (mode = 4)
%
push('C24')
%
p12 = c21(p1);
p22 = c21(p2);
gm = c14(p12,p22);
%
pull
return
