function [gm] = c26(p1,p2,dom)
%  C26:    POLPAC conversion polynomial matrices -> transfer function matrix
%
%  Usage:  gm = c26(p1,p2,dom)
%
%  This function concerts two POLPAC polynomial matrices of same
%  logical size to one POLPAC transfer function matrix.  P1
%  denotes the numerator, P2 denotes the denominator.
%
%  The polynomial matrices are represented through their roots,
%  the transfer function matrix on the other hand is represented
%  through trajectories.
%
%  This is a mixed mode operation.  The two polynomial matrices
%  are first transformed into trajectory representation, and
%  then concatenated to form the resulting transfer function matrix.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Numerator polynomial matrix (stored in mode 2)
%    p2     := Denominator polynomial matrix (stored in mode 2)
%    dom    := Row vector containing the domain information
%
%  Output Parameter:
%  -----------------
%
%    gm     := Resulting transfer function matrix (stored in mode 6)
%
push('C26')
%
p12 = c23(p1,dom);
p22 = c23(p2,dom);
gm = c36(p12,p22);
%
pull
return
