function [ps] = c27(pm,qm,rm,wm)
%  C27:    POLPAC conversion polynomial matrices -> polynomial matrix system
%
%  Usage:  ps = c27(pm,qm,rm,wm)
%
%  This function concatenates the four factorized polynomial matrices
%  PM, QM, RM, and WM into one nonfactorized polynomial system
%  description.
%
%  This mixed mode operation first converts each of the four polynomial
%  matrices into their nonfactorized forms, then concatenates them to
%  their final form.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Polynomial partial state coupling matrix (mode = 2)
%    qm     := Polynomial input coupling matrix (mode = 2)
%    rm     := Polynomial output coupling matrix (mode = 2)
%    wm     := Polynomial input/output coupling matrix (mode = 2)
%
%  Output Parameter:
%  -----------------
%
%    ps     := Polynomial matrix system description (mode = 7)
%
push('C27')
%
p1 = c21(pm);
q1 = c21(qm);
r1 = c21(rm);
w1 = c21(wm);
ps = c17(p1,q1,r1,w1);
%
pull
return
