function [ps] = c29(pm,qm,rm,wm,dom)
%  C29:    POLPAC conversion polynomial matrices -> polynomial matrix system
%
%  Usage:  ps = c29(pm,qm,rm,wm,dom)
%
%  This function converts the four polynomial matrices PM, QM,
%  RM, and WM into one POLPAC polynomial matrix system description.
%
%  All input polynomials must be stored in mode 2.  The resulting
%  system will be stored in mode 9.  The DOMAIN for the transition
%  must be user specified.
%
%  This is a mixed mode operation.  All polynomial matrices are
%  first converted to their trajectory representation, and then
%  they are concatenated to the system description.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Polynomial partial state coupling matrix (mode = 2)
%    qm     := Polynomial input coupling matrix (mode = 2)
%    rm     := Polynomial output coupling matrix (mode = 2)
%    wm     := Polynomial input/output coupling matrix (mode = 2)
%    dom    := Row vector containing the domain information
%
%  Output Parameter:
%  -----------------
%
%    ps     := Polynomial system description (mode = 9)
%
push('C29')
%
p1 = c23(pm,dom);
q1 = c23(qm,dom);
r1 = c23(rm,dom);
w1 = c23(wm,dom);
ps = c39(p1,q1,r1,w1);
%
pull
return
