function [gm] = c34(p1,p2,mcol)
%  C34:    POLPAC conversion polynomial matrices -> transfer function matrix
%
%  Usage:  gm = c34(p1,p2,mcol)
%
%  This function concatenates two trajectory polynomial matrices
%  (mode=3) into one nonfactorized transfer function matrix
%  stored in mode=4.
%
%  No checks for consistency are performed as it can be assumed
%  that these checks take place in the underlying routines.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Trajectory numerator polynomial (mode = 3)
%    qm     := Trajectory denominator polynomial (mode = 3)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameter:
%  -----------------
%
%    gm     := Nonfactorized transfer function matrix (mode = 4)
%
push('C34')
%
%  Set default values
%
if nargin == 2,
  mcol = 0;
end
%
p12 = c31(p1,mcol);
p22 = c31(p2,mcol);
gm = c14(p12,p22);
%
pull
return
