function [gm] = c35(p1,p2,mcol)
%  C34:    POLPAC conversion polynomial matrices -> transfer function matrix
%
%  Usage:  gm = c35(p1,p2,mcol)
%
%  This function converts a numerator polynomial matrix (P1) and a
%  denominator polynomial matrix (P2) into one transfer function
%  matrix (GM).  The input data structures are stored in mode 3, the
%  output data structure is stored in mode 5.
%
%  This is a mixed mode operation.  First, we convert P1 and P2 into
%  mode 2, then we concatenate them into mode 5.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Trajectory numerator polynomial (mode = 3)
%    p2     := Trajectory denominator polynomial (mode = 3)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameter:
%  -----------------
%
%    gm     := Factorized transfer function matrix (mode = 5)
%
push('C35');
%
%  Set default values
%
if nargin == 2,
  mcol = 0;
end
%
p = c32(p1,mcol);
q = c32(p2,mcol);
gm = c25(p,q);
%
pull
return
