function [ps] = c37(pm,qm,rm,wm,mcol)
%  C37:    POLPAC conversion polynomial matrices -> polynomial matrix system
%
%  Usage:  ps = c37(pm,qm,rm,wm,mcol)
%
%  This function concatenates four trajectory polynomial
%  matrices PM, QM, RM and WM stored in POLPAC storage mode 3
%  into a nonfactorized polynomial matrix system representation
%  stored in POLPAC storage mode 7.
%
%  Input Parameters:
%  -----------------
%
%    pm     :=  Partial State polynomial matrix (POLPAC mode = 3)
%    qm     :=  Input polynomial matrix (POLPAC mode = 3)
%    rm     :=  Output polynomial matrix (POLPAC mode = 3)
%    wm     :=  Input-output polynomial matrix (POLPAC mode = 3)
%    mcol   :=  Non-negative integer which, if non-zero, equals
%               the largest allowed LOGCOL value of output matrix
%               default: mcol = 0
%
%  Output Parameter:
%  -----------------
%
%    ps     :=  System polynomial matrix (POLPAC mode = 7)
%
push('C37')
%
%  Set default values
%
if nargin == 4,
  mcol = 0;
end
%
p1 = c31(pm,mcol);
q1 = c31(qm,mcol);
r1 = c31(rm,mcol);
w1 = c31(wm,mcol);
ps = c17(p1,q1,r1,w1);
%
pull
return
