function [ps] = c38(pm,qm,rm,wm,mcol)
%  C38:    POLPAC conversion polynomial matrices -> polynomial matrix system
%
%  Usage:  ps = c38(pm,qm,rm,wm,mcol)
%
%  This function converts a polynomial matrix representation
%  consisting of PM, QM, RM, and WM, into one polynomial matrix
%  system description (PS).  The input data structures are stored
%  in mode 3, the output data structure is stored in mode 8.
%
%  This is a mixed mode operation.  First, we convert PM, QM, RM, and
%  WM into mode 2, then we concatenate them into mode 8.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Trajectory polynomial matrix (mode = 3)
%    qm     := Trajectory polynomial matrix (mode = 3)
%    rm     := Trajectory polynomial matrix (mode = 3)
%    wm     := Trajectory polynomial matrix (mode = 3)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameter:
%  -----------------
%
%    gm     := Unfactorized polynomial matrix system (mode = 8)
%
push('C38')
%
%  Set default values
%
if nargin == 4,
  mcol = 0;
end
%
p1 = c32(pm,mcol);
q1 = c32(qm,mcol);
r1 = c32(rm,mcol);
w1 = c32(wm,mcol);
ps = c28(p1,q1,r1,w1);
%
pull
return
