function [pm,qm] = c42(gm)
%  C42:    POLPAC conversion transfer function matrix -> polynomial matrices
%
%  Usage:  [pm,qm] = c42(gm)
%
%  This function decomposes one nonfactorized transfer function matrix
%  into its numerator and its denominator polynomial matrices.  These
%  are returned as factorized polynomial matrices.
%
%  This mixed mode operation first decomposes the transfer function
%  matrix into nonfactorized polynomial matrices which are subsequently
%  converted to their factorized forms.
%
%  Input Parameter:
%  ----------------
%
%    gm     := Nonfactorized transfer function matrix (mode = 4)
%
%  Output Parameters:
%  ------------------
%
%    pm     := Factorized numerator polynomial matrix (mode = 2)
%    qm     := Factorized denominator polynomial matrix (mode = 2)
%
push('C42')
%
[p1,q1] = c41(gm);
pm = c12(p1);
qm = c12(q1);
%
pull
return
