function [pm,qm] = c43(gm,dom)
%  C43:    POLPAC conversion transfer function matrix -> polynomial matrices
%
%  Usage:  [pm,qm] = c43(gm,dom)
%
%  This function converts a nonfactorized transfer function matrix
%  (mode=4) into its numerator and denominator polynomial matrices
%  stored in mode=3.
%
%  No checks for consistency are performed as it can be assumed
%  that these checks take place in the underlying routines.
%
%  Input Parameters:
%  -----------------
%
%    gm     := Nonfactorized transfer function matrix (mode = 4)
%    dom    := Matlab row vector containing the domain information
%
%  Output Parameters:
%  ------------------
%
%    pm     := Trajectory numerator polynomial (mode = 3)
%    qm     := Trajectory denominator polynomial (mode = 3)
%
push('C43')
%
[p1,q1] = c41(gm);
pm = c13(p1,dom);
qm = c13(q1,dom);
%
pull
return
