function [g2] = c45(g1)
%  C45:    POLPAC conversion transfer function matrix: coefficients -> roots
%
%  Usage:  g2 = c45(g1)
%
%  This function transforms a nonfactorized transfer function matrix
%  into its factorized form.
%
%  This mixed mode operation is accomplished by decomposing the input
%  transfer function matrix into its numerator and denominator
%  polynomials which are then converted separately into their
%  factorized forms.  Finally, they are recombined into the
%  factorized transfer function matrix.
%
%  Input Parameter:
%  ----------------
%
%    g1     := Nonfactorized transfer function matrix (mode = 4)
%
%  Output Parameter:
%  -----------------
%
%    g2     := Factorized transfer function matrix (mode = 5)
%
push('C45')
%
[p,q] = c41(g1);
p = c12(p);
q = c12(q);
g2 = c25(p,q);
%
pull
return
