function [ps7] = c47(g4)
%  C47:    POLPAC conversion transfer function matrix -> polynomial matrix syst.
%
%  Usage:  ps7 = c47(g4)
%
%  This function converts a non-factorized transfer function matrix (G4) stored
%  in POLPAC storage mode 4 into a non-factorized polynomial matrix system
%  representation stored in POLPAC storage mode 7.
%
%  Input Parameter:
%  ----------------
%
%   g4    :=  Non-factorized transfer function matrix (mode = 4)
%
%  Output Parameter:
%  -----------------
%
%   ps7   :=  Non-factorized polynomial matrix system (mode = 7)
%             in controller-canonical form
% 
push('C47')
global debg
%
%  First of all SQUEEZE G4.
% 
gm = squeeze(g4);
% 
%  UNPACK data structure.
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
%
%  Check the consistency
%
if debg == 3,
  if mode ~= 4,
    disp('C47: Error - Input must be in mode 4'),
    mode,
    abort,
  end,
end
%
%  Find the logical dimension of GM
%
[lr,lc] = logdim(gm);
%
%  Extract the W matrix.
%
[gms,wm1] = strictprop(gm);
%
%  UNPACK GMS
%
[modes,logcols,dtypes,stype] = unpack(gms(1,1));
%
%  If logcols == 1, GMS is 0.
%
if logcols == 1,
  pm1 = [];
  qm1 = [];
  rm1 = [];
  ps7 = c17(pm1,qm1,rm1,wm1);
  pull,
  return,
end
%
%  Build up PM1, and RM1 matrices
%
gmk = gget(gms,[1:lr],1);
[pm,cdp] = commonden(gmk);
for i=2:lc,
  gmk = gget(gms,[1:lr],i);
  [pmi,cdpi] = commonden(gmk);
  cdp = dconc(cdp,cdpi);
  pm = hconc(pm,pmi);
end
pm1 = cdp;
rm1 = pm;
%
%  Now make the QM1 matrix
%
[lpr,lpc] = logdim(pm1);
[lrr,lrc] = logdim(rm1);
[lwr,lwc] = logdim(wm1);
[mode,logcol,dtype,stype] = unpack(pm1(1,1));
dom = 0;
qm1 = eyep(lpr,lwc,mode,logcol,stype,dom);
%
%  Build the system matrix representation
%
ps7 = c17(pm1,qm1,rm1,wm1);
%
%  Final SQUEEZE
%
ps7 = squeeze(ps7);
%
pull
return
