function [s] = c50(g5)
%  C50:    POLPAC conversion transfer function matrix (roots) -> state-space
%
%  Usage: s = c50(g5)
%
%  This function converts a transfer function matrix in POLPAC mode 5
%  into a state space system representation in POLPAC mode 0.
%
%  The mode 0 system S will be generated in controller-canonical form.
%
%  Input Parameter:
%  ----------------
%
%    g5     := Transfer function matrix (POLPAC mode 5).
%
%  Output Parameter:
%  -----------------
%
%    s      := System matrix (POLPAC mode 0).
%
push('C50')
%
%  Don't check for mode 5 yet since this gets checked immediately upon
%  entry into C54.
%
[p,q] = c52(g5);
p = c21(p);
q = c21(q);
g4 = c14(p,q);
s = c40(g4);
%
pull
return
