function [pm,qm] = c51(gm)
%  C51:    POLPAC conversion transfer function matrix -> polynomial matrices
%
%  Usage:  [pm,qm] = c51(gm)
%
%  This function decomposes one factorized transfer function matrix
%  into its numerator and its denominator polynomial matrices.  These
%  are returned as nonfactorized polynomial matrices.
%
%  This mixed mode operation first decomposes the transfer function
%  matrix into factorized polynomial matrices which are subsequently
%  converted to their nonfactorized forms.
%
%  Input Parameter:
%  ----------------
%
%    gm     := Factorized transfer function matrix (mode = 5)
%
%  Output Parameters:
%  ------------------
%
%    pm     := Nonfactorized numerator polynomial matrix (mode = 1)
%    qm     := Nonfactorized denominator polynomial matrix (mode = 1)
%
push('C51')
%
[p1,q1] = c52(gm);
pm = c21(p1);
qm = c21(q1);
%
pull
return
