function [pm,qm] = c53(gm,dom)
%  C53:    POLPAC conversion transfer function matrix -> polynomial matrices
%
%  Usage:  [pm,qm] = c53(gm,dom)
%
%  This function transforms a factorized transfer function matrix into
%  its numerator and denominator polynomials which are then converted
%  to their trajectory representation.
%
%  Since the domain information is not contained in the transfer
%  function matrix, it must be user supplied.
%
%  This is a mixed mode operation which calls upon two more primitive
%  conversion routines.
%
%  Input Parameters:
%  -----------------
%
%    gm     := factorized transfer function matrix (mode = 5)
%    dom    := row vector containing the domain
%
%  Output Parameters:
%  ------------------
%
%    pm     := trajectory numerator polynomial (mode = 3)
%    qm     := trajectory denominator polynomial (mode = 3)
%
push('C53')
%
[p1,q1] = c52(gm);
pm = c23(p1,dom);
qm = c23(q1,dom);
%
pull
return
