function [g2] = c54(g1)
%  C54:    POLPAC conversion transfer function matrix: roots -> coefficients
%
%  Usage:  g2 = c54(g1)
%
%  This function transforms a factorized transfer function matrix
%  into its nonfactorized form.
%
%  This mixed mode operation is accomplished by decomposing the input
%  transfer function matrix into its numerator and denominator
%  polynomials which are then converted separately into their
%  nonfactorized forms.  Finally, they are recombined into the
%  nonfactorized transfer function matrix.
%
%  Input Parameter:
%  ----------------
%
%    g1     := Factorized transfer function matrix (mode = 5)
%
%  Output Parameter:
%  -----------------
%
%    g2     := Nonfactorized transfer function matrix (mode = 4)
%
push('C54')
%
[p,q] = c52(g1);
p = c21(p);
q = c21(q);
g2 = c14(p,q);
%
pull
return
