function [g2] = c56(g1,dom)
%  C56:    POLPAC conversion transfer function matrix: roots -> trajectories
%
%  Usage:  g2 = c56(g1,dom)
%
%  This function converts a factorized transfer function matrix to
%  its trajectory form.  As this operation is applied independently
%  to the numerator and to the denominator polynomials, it is easiest
%  to simple extract the two polynomial matrices in factorized form,
%  use then the already available transformation routine to go into
%  trajectory representation, and finally concatenate the resulting
%  polynomial matrices back together.
%
%  Input Parameters:
%  -----------------
%
%    g1     := Factorized transfer function matrix (mode = 5)
%    dom    := Row vector containing the domain
%
%  Output Parameter:
%  -----------------
%
%    g2     := Trajectory transfer function matrix (mode = 6)
%
push('C56')
%
[p,q] = c52(g1);
p = c23(p,dom);
q = c23(q,dom);
g2 = c36(p,q);
%
pull
return
