function [ps8] = c58(g5)
%  C58:    POLPAC conversion transfer function matrix -> polynomial matrix syst.
%
%  Usage:  ps8 = c58(g5)
%
%  This function converts a factorized transfer function matrix (G5) stored
%  in POLPAC storage mode 5 into a factorized polynomial matrix system
%  representation stored in POLPAC storage mode 8.
%
%  Input Parameter:
%  ----------------
%
%   g5    :=  Factorized transfer function matrix (mode = 5)
%
%  Output Parameter:
%  -----------------
%
%   ps8   :=  Factorized polynomial matrix system (mode = 8)
%             in controller-canonical form
% 
push('C58')
global debg
%
%  First of all SQUEEZE G5.
% 
gm = squeeze(g5);
% 
%  UNPACK data structure.
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
%
%  Check the consistency
%
if debg == 3,
  if mode ~=5,
    disp('C58: Error - Input must be in mode 5'),
    mode,
    abort,
  end,
end
%
%  Find the logical dimension of GM
%
[lr,lc] = logdim(gm);
%
%  Extract the W matrix.
%
[gms,wm2] = strictprop(gm);
%
%  UNPACK GMS
%
[modes,logcols,dtypes,stype] = unpack(gms(1,1));
%
%  If logcols == 1, GMS is 0.
%
if logcols == 1,
  pm2 = [];
  qm2 = [];
  rm2 = [];
  ps8 = c28(pm2,qm2,rm2,wm2);
  pull,
  return,
end
%
%  Build up PM2, and RM2 matrices
%
gmk = gget(gms,[1:lr],1);
[pm,cdp] = commonden(gmk);
for i=2:lc,
  gmk = gget(gms,[1:lr],i);
  [pmi,cdpi] = commonden(gmk);
  cdp = dconc(cdp,cdpi);
  pm = hconc(pm,pmi);
end
pm2 = cdp;
rm2 = pm;
%
%  Now make the QM2 matrix
%
[lpr,lpc] = logdim(pm1);
[lrr,lrc] = logdim(rm1);
[lwr,lwc] = logdim(wm1);
[mode,logcol,dtype,stype] = unpack(pm2(1,1));
dom = 0;
qm2 = eyep(lpr,lwc,mode,logcol,stype,dom);
%
%  Build the system matrix representation
%
ps8 = c28(pm2,qm2,rm2,wm2);
%
%  Final SQUEEZE
%
ps8 = squeeze(ps8);
%
pull
return
