function [pm,qm] = c61(gm,mcol)
%  C61:    POLPAC conversion transfer function matrix -> polynomial matrices
%
%  Usage:  [pm,qm] = c61(gm,mcol)
%
%  This function converts a transfer function matrix (GM) into
%  a numerator (PM) and denominator (QM) polynomial matrix representation.
%  The input data structure is stored in mode 6, and the output data
%  structures are stored in mode 1.
%
%  This is a mixed mode operation.  First, we convert GM into P and Q
%  in mode 3, then we separate them into mode 1.
%
%  Input Parameters:
%  -----------------
%
%    gm     := Trajectory transfer function matrix (mode = 6)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameters:
%  ------------------
%
%    pm     := Nonfactorized numerator polynomial matrix (mode = 1)
%    qm     := Nonfactorized denominator polynomial matrix (mode = 1)
%
push('C61')
%
%  Set default values
%
if nargin == 1,
  mcol = 0;
end
%
[p1,q1] = c63(gm);
pm = c31(p1,mcol);
qm = c31(q1,mcol);
%
pull
return
