function [g2] = c64(g1,mcol)
%  C64:    POLPAC conversion transfer function matrix: traj. -> coefficients
%
%  Usage:  g2 = c64(g1,mcol)
%
%  This function converts a trajectory transfer function matrix (G1)
%  into an unfactorized transfer function matrix representation (G2).
%  The input data structure is stored in mode 6, and the output data
%  structure is stored in mode 4.
%
%  This is a mixed mode operation.  First, we convert G1 into P and Q
%  in mode 1, then we concatenate them into mode 4.
%
%  Input Parameters:
%  -----------------
%
%    g1     := Trajectory transfer function matrix (mode = 6)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameter:
%  -----------------
%
%    g2     := Unfactorized transfer function matrix (mode = 4)
%
%
push('C64')
%
%  Set default values
%
if nargin == 1,
  mcol = 0;
end
%
[p,q] = c63(g1);
p = c31(p,mcol);
q = c31(q,mcol);
g2 = c14(p,q);
%
pull  
return
