function [g2] = c65(g1,mcol)
%  C65:    POLPAC conversion transfer function matrix: trajectories -> roots
%
%  Usage:  g2 = c65(g1,mcol)
%
%  This function converts a trajectory transfer function matrix (G1)
%  into a factorized transfer function matrix representation (G2).
%  The input data structure is stored in mode 6, and the output data
%  structure is stored in mode 5.
%
%  This is a mixed mode operation.  First, we convert G1 into P and Q
%  in mode 2, then we concatenate them into mode 5.
%
%  Input Parameters:
%  -----------------
%
%    g1     := Trajectory transfer function matrix (mode = 6)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameter:
%  ------------------
%
%    g2     := Unfactorized transfer function matrix (mode = 5)
%
%
push('C65')
%
%  Set default values
%
if nargin == 1,
  mcol = 0;
end
%
[p,q] = c63(g1);
p = c32(p,mcol);
q = c32(q,mcol);
g2 = c25(p,q);
%
pull
return
