function [g2] = c66(g1,dom)
%  C66:    POLPAC conversion transfer function matrix traj.: domain change
%
%  Usage:  g2 = c66(g1,dom)
%
%  This function converts a trajectory transfer function matrix (G1)
%  into a trajectory transfer function matrix representation (G2) with
%  a new domain. The input data structure is stored in mode 6, and 
%  the output data structure is stored in mode 6, with a new domain
%  base.
%
%  First, we convert G1 into P and Q in mode 3, we change the domain
%  while in mode 3, then we concatenate them into mode 6.
%
%  The new DOMAIN obviously needs to be user supplied.
%
%  Input Parameters:
%  -----------------
%
%    g1     := Trajectory transfer function matrix (mode = 6)
%    dom    := Matlab row vector containing the new domain.
%
%  Output Parameter:
%  ------------------
%
%    g2     := Trajectory transfer function matrix (mode = 6)
%
%
push('C66')
%
[p,q] = c63(g1);
p1 = c33(p,dom);
q1 = c33(q,dom);
g2 = c36(p1,q1);
%
pull
return
