function [ps9] = c69(g6)
%  C69:    POLPAC conversion transfer function matrix -> polynomial matrix syst.
%
%  Usage:  ps9 = c69(g6)
%
%  This function converts a trajectory transfer function matrix (G6) stored
%  in POLPAC storage mode 6 into a trajectory polynomial matrix system
%  representation stored in POLPAC storage mode 9.
%
%  Input Parameter:
%  ----------------
%
%   g6    :=  Trajectory transfer function matrix (mode = 6)
%
%  Output Parameter:
%  -----------------
%
%   ps9   :=  Trajectory polynomial matrix system (mode = 9)
%             in controller-canonical form
% 
push('C69')
global debg
%
%  First of all SQUEEZE G6.
% 
gm = squeeze(g6);
% 
%  UNPACK data structure.
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
%
% Check the consistency
%
if debg == 3,
  if mode ~=6,
    disp('C69: Error - Input must be in mode 6'),
    mode,
    abort,
  end,
end
%
%  Find the logical dimension of GM
%
[lr,lc] = logdim(gm);
%
%  Extract the W matrix.
%
[gms,wm2] = strictprop(gm);
%
%  UNPACK GMS
%
[modes,logcols,dtypes,stype] = unpack(gms(1,1));
%
%  If logcols == 1, GMS is 0.
%
if logcols == 1,
  pm3 = [];
  qm3 = [];
  rm3 = [];
  ps9 = c39(pm3,qm3,rm3,wm3);
  pull,
  return,
end
%
%  Build up PM3, and RM3 matrices
%
gmk = gget(gms,[1:lr],1);
[pm,cdp] = commonden(gmk);
for i=2:lc,
  gmk = gget(gms,[1:lr],i);
  [pmi,cdpi] = commonden(gmk);
  cdp = dconc(cdp,cdpi);
  pm = hconc(pm,pmi);
end
pm3 = cdp;
rm3 = pm;
%
%  Now make the QM3 matrix
%
[lpr,lpc] = logdim(pm1);
[lrr,lrc] = logdim(rm1);
[lwr,lwc] = logdim(wm1);
[mode,logcol,dtype,stype] = unpack(pm3(1,1));
dom = domain(pm3);
qm3 = eyep(lpr,lwc,mode,logcol,stype,dom);
%
% Build the system matrix representation
%
ps9 = c39(pm3,qm3,rm3,wm3);
%
%  Final SQUEEZE
%
ps9 = squeeze(ps9);
%
pull
return
