function [pm,qm,rm,wm] = c72(ps)
%  C72:    POLPAC conversion polynomial matrix system -> polynomial matrices
%
%  Usage:  [pm,qm,rm,wm] = c72(ps)
%
%  This function converts an unfactorized polynomial matrix system
%  description (PS) into it's factorized polynomial matrices (PM, QM,
%  RM, WM).  The input data structure is stored in mode 7, and the
%  output data structures are stored in mode 2.
%
%  This is a mixed mode operation.  First, we convert PS into P1, Q1,
%  R1, and W1 in mode 1, then we convert them into mode 2.
%
%  Input Parameter:
%  ----------------
%
%    ps     := Nonfactorized polynomial matrix system (mode = 7)
%
%  Output Parameters:
%  ------------------
%
%    pm     := Factorized polynomial matrix (mode = 2)
%    qm     := Factorized polynomial matrix (mode = 2)
%    rm     := Factorized polynomial matrix (mode = 2)
%    wm     := Factorized polynomial matrix (mode = 2)
%
push('C72')
%
[p1,q1,r1,w1] = c71(ps);
pm = c12(p1);
qm = c12(q1);
rm = c12(r1);
wm = c12(w1);
%
pull
return
