function [pm,qm,rm,wm] = c73(ps,dom)
%  C73:    POLPAC conversion polynomial matrix system -> polynomial matrices
%
%  Usage:  [pm,qm,rm,wm] = c73(ps,dom)
%
%  This function converts an unfactorized polynomial matrix system
%  description (PS) into its trajectorized polynomial matrices (PM, QM,
%  RM, WM).  The input data structure is stored in mode 7, and the
%  output data structures are stored in mode 3.
%
%  This is a mixed mode operation.  First, we convert PS into P1, Q1,
%  R1, and W1 in mode 1, then we convert them into mode 3.
%
%  Input Parameters:
%  -----------------
%
%    ps     := Unfactorized polynomial matrix system (mode = 7)
%    dom    := Matlab row vector containing the new domain.
%
%  Output Parameters:
%  ------------------
%
%    pm     := Trajectory polynomial matrix (mode = 3)
%    qm     := Trajectory polynomial matrix (mode = 3)
%    rm     := Trajectory polynomial matrix (mode = 3)
%    wm     := Trajectory polynomial matrix (mode = 3)
%
push('C73')
%
[p1,q1,r1,w1] = c71(ps);
pm = c13(p1,dom);
qm = c13(q1,dom);
rm = c13(r1,dom);
wm = c13(w1,dom);
%
pull
return
