function [g4] = c74(ps7)
%  C74:    POLPAC conversion polynomial matrix syst. -> transfer function matrix
%
%  Usage:  g4 = c74(ps7)
%
%  This function converts a a non-factorized polynomial matrix system
%  representation stored in POLPAC storage mode 7 into a non-factorized
%  transfer function matrix (G4) stored in POLPAC storage mode 4.
%
%  Input Parameter:
%  ----------------
%
%   ps7   :=  Non-factorized polynomial matrix system (mode = 7)
%
%  Output Parameter:
%  -----------------
%
%   g4    :=  Non-factorized transfer function matrix (mode = 4)
% 
push('C74')
%
%  First of all SQUEEZE PS7
%
ps = squeeze(ps7);
%
%  It is unnecessary to check the consistency since
%  c71 will do it.  Get the P, Q, R, and W matrices.
%
[pm,qm,rm,wm] = c71(ps);
%
%  Check for special case of pm = []
%
if isempty(pm),
  [lwr,lwc] = logdim(wm);
  [modw,logcw,dtypw,stypw] = unpack(wm(1,1));
  domw = domain(wm);
  wqm = eyep(lwr,lwc,modw,logcw,stypw,domw);
  g4 = c14(wm,wqm);
  pull,
  return,
end
%
%  Build the transfer function matrix
%
g4 = addg(multg(multg(rm,invp(pm)),qm),wm);
%
%  Do a final SQUEEZE
%
g4 = squeeze(g4);
%
pull
return 
