function [p2] = c78(p1)
%  C78:    POLPAC conversion polynomial matrix system: coefficients -> roots
%
%  Usage:  [p2] = c78(p1)
%
%  This function converts an nonfactorized polynomial matrix system
%  description (P1) into a factorized polynomial matrix system
%  description (P2).  The input data structure is stored in mode 7,
%  and the output data structure is stored in mode 8.
%
%  This is a mixed mode operation.  First, we convert P1 into PM, QM,
%  RM, and WM mode 2, then we combine them into mode 8.
%
%  Input Parameter:
%  ----------------
%
%    p1     := Nonfactorized polynomial matrix system (mode = 7)
%
%  Output Parameter:
%  -----------------
%
%    p2     := Factorized polynomial matrix system (mode = 8)
%
push('C78')
%
[pm,qm,rm,wm] = c71(p1);
pm = c12(pm);
qm = c12(qm);
rm = c12(rm);
wm = c12(wm);
p2 = c28(pm,qm,rm,wm);
%
pull
return
