function [p2] = c79(p1,dom)
%  C79:    POLPAC conversion polynomial matrix system: coefficients -> traj.
%
%  Usage:  [p2] = c79(p1,dom)
%
%  This function converts an unfactorized polynomial matrix system
%  description (P1) into a trajectory polynomial matrix system
%  description (P2).  The input data structure is stored in mode 7,
%  and the output data structure is stored in mode 9.
%
%  This is a mixed mode operation.  First, we convert P1 into PM, QM,
%  RM, and WM in mode 3, then we combine them into mode 9.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Unfactorized polynomial matrix system (mode = 7)
%    dom    := Matlab row vector containing the new domain.
%
%  Output Parameter:
%  -----------------
%
%    p2     := Trajectory polynomial matrix system (mode = 9)
%
%
pusH('C79')
%
[pm,qm,rm,wm] = c71(p1);
pm = c13(pm,dom);
qm = c13(qm,dom);
rm = c13(rm,dom);
wm = c13(wm,dom);
p2 = c39(pm,qm,rm,wm);
%
pull
return
