function [pm,qm,rm,wm] = c81(ps)
%  C81:    POLPAC conversion polynomial matrix system -> polynomial matrices
%
%  Usage:  [pm,qm,rm,wm] = c81(ps)
%
%  This function converts a factorized polynomial matrix system
%  description (PS) into its unfactorized polynomial matrices (PM, QM,
%  RM, WM).  The input data structure is stored in mode 8, and the
%  output data structures are stored in mode 1.
%
%  This is a mixed mode operation.  First, we convert PS into P1, Q1,
%  R1, and W1 in mode 2, then we convert them into mode 1.
%
%  Input Parameter:
%  ----------------
%
%    ps     := Factorized polynomial matrix system (mode = 8)
%
%  Output Parameters:
%  ------------------
%
%    pm     := Unfactorized polynomial matrix (mode = 1)
%    qm     := Unfactorized polynomial matrix (mode = 1)
%    rm     := Unfactorized polynomial matrix (mode = 1)
%    wm     := Unfactorized polynomial matrix (mode = 1)
%
push('C81')
%
[p1,q1,r1,w1] = c82(ps);
pm = c21(p1);
qm = c21(q1);
rm = c21(r1);
wm = c21(w1);
%
pull
return
