function [pm,qm,rm,wm] = c83(ps,dom)
%  C83:    POLPAC conversion polynomial matrix system -> polynomial matrices
%
%  Usage:  [pm,qm,rm,wm] = c83(ps,dom)
%
%  This function converts a factorized polynomial matrix system
%  description (PS) into its trajectorized polynomial matrices (PM, QM,
%  RM, WM).  The input data structure is stored in mode 8, and the
%  output data structures are stored in mode 3.
%
%  This is a mixed mode operation.  First, we convert PS into P1, Q1,
%  R1, and W1 in mode 2, then we convert them into mode 3.
%
%  Input Parameters:
%  -----------------
%
%    ps     := Unfactorized polynomial matrix system (mode = 8)
%    dom    := Matlab row vector containing the new domain.
%
%  Output Parameters:
%  ------------------
%
%    pm     := Trajectory polynomial matrix (mode = 3)
%    qm     := Trajectory polynomial matrix (mode = 3)
%    rm     := Trajectory polynomial matrix (mode = 3)
%    wm     := Trajectory polynomial matrix (mode = 3)
%
push('C83')
%
[p1,q1,r1,w1] = c82(ps);
pm = c23(p1,dom);
qm = c23(q1,dom);
rm = c23(r1,dom);
wm = c23(w1,dom);
%
pull
return
