function [g5] = c85(ps8)
%  C85:    POLPAC conversion polynomial matrix syst. -> transfer function matrix
%
%  Usage:  g5 = c85(ps8)
%
%  This function converts a a factorized polynomial matrix system
%  representation stored in POLPAC storage mode 8 into a factorized
%  transfer function matrix (G5) stored in POLPAC storage mode 5.
%
%  Input Parameter:
%  ----------------
%
%   ps8   :=  Factorized polynomial matrix system (mode = 8)
%
%  Output Parameter:
%  -----------------
%
%   g5    :=  Factorized transfer function matrix (mode = 5)
% 
push('C85')
%
%  First of all SQUEEZE PS8
%
ps = squeeze(ps8);
%
%  It is unnecessary to check the consistency since
%  c82 will do it.  Get the P, Q, R, and W matrices.
%
[pm,qm,rm,wm] = c82(ps);
%
%  Check for special case of pm = []
%
if isempty(pm),
  [lwr,lwc] = logdim(wm);
  [modw,logcw,dtypw,stypw] = unpack(wm(1,1));
  domw = domain(wm);
  wqm = eyep(lwr,lwc,modw,logcw,stypw,domw);
  g4 = c25(wm,wqm);
  pull,
  return,
end
%
%  Build the transfer function matrix
%
g5 = addg(multg(multg(rm,invp(pm)),qm),wm);
%
%  Do a final SQUEEZE
%
g5 = squeeze(g5);
%
pull
return 
