function [p2] = c87(p1)
%  C87:    POLPAC conversion polynomial matrix system: roots -> coefficients
%
%  Usage:  p2 = c87(p1)
%
%  This function converts a factorized polynomial matrix system
%  description (P1) into an unfactorized polynomial matrix system
%  description (P2).  The input data structure is stored in mode 8,
%  and the output data structure is stored in mode 7.
%
%  This is a mixed mode operation.  First, we convert P1 into PM, QM,
%  RM, and WM in mode 1, then we combine them into mode 7.
%
%  Input Parameter:
%  ----------------
%
%    p1     := Factorized polynomial matrix system (mode = 8)
%
%  Output Parameter:
%  -----------------
%
%    p2     := Unfactorized polynomial matrix system (mode = 7)
%
push('C87')
%
[pm,qm,rm,wm] = c82(p1);
pm = c21(pm);
qm = c21(qm);
rm = c21(rm);
wm = c21(wm);
p2 = c17(pm,qm,rm,wm);
%
pull
return
