function [p2] = c89(p1,dom)
%  C89:    POLPAC conversion polynomial matrix system: roots -> trajectories
%
%  Usage:  p2 = c89(p1,dom)
%
%  This function converts a factorized polynomial matrix system
%  description (P1) into a trajectory polynomial matrix system
%  description (P2).  The input data structure is stored in mode 8,
%  and the output data structure is stored in mode 9.
%
%  This is a mixed mode operation.  First, we convert P1 into PM, QM,
%  RM, and WM in mode 3, then we combine them into mode 9.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Factorized polynomial matrix system (mode = 8)
%    dom    := Matlab row vector containing the new domain.
%
%  Output Parameter:
%  -----------------
%
%    p2     := Trajectory polynomial matrix system (mode = 9)
%
%
push('C89')
%
[pm,qm,rm,wm] = c82(p1);
pm = c23(pm,dom);
qm = c23(qm,dom);
rm = c23(rm,dom);
wm = c23(wm,dom);
p2 = c39(pm,qm,rm,wm);
%
pull
return
