function [pm,qm,rm,wm] = c91(ps,mcol)
%  C91:    POLPAC conversion polynomial matrix system -> polynomial matrices
%
%  Usage:  [pm,qm,rm,wm] = c91(ps,mcol)
%
%  This function converts a trajectory polynomial matrix system
%  description (PS) into its unfactorized polynomial matrices (PM, QM,
%  RM, WM).  The input data structure is stored in mode 9, and the
%  output data structures are stored in mode 1.
%
%  This is a mixed mode operation.  First, we convert PS into P1, Q1,
%  R1, and W1 in mode 3, then we convert them into mode 1.
%
%  Input Parameters:
%  -----------------
%
%    ps     := Unfactorized polynomial matrix system (mode = 9)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameters:
%  ------------------
%
%    pm     := Unfactorized polynomial matrix (mode = 1)
%    qm     := Unfactorized polynomial matrix (mode = 1)
%    rm     := Unfactorized polynomial matrix (mode = 1)
%    wm     := Unfactorized polynomial matrix (mode = 1)
%
push('C91')
%
%  Set default values
%
if nargin == 1,
  mcol = 0;
end
%
[p1,q1,r1,w1] = c93(ps);
pm = c31(p1,mcol);
qm = c31(q1,mcol);
rm = c31(r1,mcol);
wm = c31(w1,mcol);
%
pull
return
