function [pm,qm,rm,wm] = c92(ps,mcol)
%  C92:    POLPAC conversion polynomial matrix system -> polynomial matrices
%
%  Usage:  [pm,qm,rm,wm] = c92(ps,mcol)
%
%  This function converts a trajectory polynomial matrix system
%  description (PS) into it's factorized polynomial matrices (PM, QM,
%  RM, WM).  The input data structure is stored in mode 9, and the
%  output data structures are stored in mode 2.
%
%  This is a mixed mode operation.  First, we convert PS into P1, Q1,
%  R1, and W1 in mode 3, then we convert them into mode 2.
%
%  Input Parameters:
%  -----------------
%
%    ps     := Unfactorized polynomial matrix system (mode = 7)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameters:
%  ------------------
%
%    pm     := Factorized polynomial matrix (mode = 2)
%    qm     := Factorized polynomial matrix (mode = 2)
%    rm     := Factorized polynomial matrix (mode = 2)
%    wm     := Factorized polynomial matrix (mode = 2)
%
push('C92')
%
%  Set default values
%
if nargin == 1,
  mcol = 0;
end
%
[p1,q1,r1,w1] = c93(ps);
pm = c32(p1,mcol);
qm = c32(q1,mcol);
rm = c32(r1,mcol);
wm = c32(w1,mcol);
%
pull
return
