function [g6] = c96(ps9)
%  C96:    POLPAC conversion polynomial matrix syst. -> transfer function matrix
%
%  Usage:  g6 = c96(ps9)
%
%  This function converts a a trajectory polynomial matrix system
%  representation stored in POLPAC storage mode 9 into a trajectory
%  transfer function matrix (G6) stored in POLPAC storage mode 6.
%
%  Input Parameter:
%  ----------------
%
%   ps9   :=  Trajectory polynomial matrix system (mode = 9)
%
%  Output Parameter:
%  -----------------
%
%   g6    :=  Trajectory transfer function matrix (mode = 6)
% 
push('C96')
%
%  First of all SQUEEZE PS9
%
ps = squeeze(ps9);
%
%  It is unnecessary to check the consistency since
%  c93 will do it.  Get the P, Q, R, and W matrices.
%
[pm,qm,rm,wm] = c93(ps);
%
%  Check for special case of pm = []
%
if isempty(pm),
  [lwr,lwc] = logdim(wm);
  [modw,logcw,dtypw,stypw] = unpack(wm(1,1));
  domw = domain(wm);
  wqm = eyep(lwr,lwc,modw,logcw,stypw,domw);
  g4 = c36(wm,wqm);
  pull,
  return,
end
%
%  Build the transfer function matrix
%
g6 = addg(multg(multg(rm,invp(pm)),qm),wm);
%
%  Do a final SQUEEZE
%
g6 = squeeze(g6);
%
pull
return 
