function [p2] = c97(p1,mcol)
%  C97:    POLPAC conversion polynomial matrix system: traj. -> coefficients
%
%  Usage:  p2 = c97(p1,mcol)
%
%  This function converts a trajectory polynomial matrix system
%  description (P1) into an unfactorized polynomial matrix system
%  description (P2).  The input data structure is stored in mode 9,
%  and the output data structure is stored in mode 7.
%
%  This is a mixed mode operation.  First, we convert P1 into PM, QM,
%  RM, and WM in mode 1, then we combine them into mode 7.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Factorized polynomial matrix system (mode = 8)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameter:
%  -----------------
%
%    p2     := Unfactorized polynomial matrix system (mode = 7)
%
push('C97')
%
%  Set default values
%
if nargin == 1,
  mcol = 0;
end
%
[pm,qm,rm,wm] = c93(p1);
pm = c31(pm,mcol);
qm = c31(qm,mcol);
rm = c31(rm,mcol);
wm = c31(wm,mcol);
p2 = c17(pm,qm,rm,wm);
%
pull
return
