function [p2] = c98(p1,mcol)
%  C98:    POLPAC conversion polynomial matrix system: trajectories -> roots
%
%  Usage:  p2 = c98(p1,mcol)
%
%  This function converts a trajectory polynomial matrix system
%  description (P1) into a factorized polynomial matrix system
%  description (P2).  The input data structure is stored in mode 9,
%  and the output data structure is stored in mode 8.
%
%  This is a mixed mode operation.  First, we convert P1 into PM, QM,
%  RM, and WM mode 2, then we combine them into mode 8.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Unfactorized polynomial matrix system (mode = 9)
%    mcol   := Non-negative integer which, if non-zero, equals
%              the largest allowed LOGCOL value of output matrix
%              default: mcol = 0
%
%  Output Parameter:
%  -----------------
%
%    p2     := Factorized polynomial matrix system (mode = 8)
%
push('C98')
%
%  Set default values
%
if nargin == 1,
  mcol = 0;
end
%
[pm,qm,rm,wm] = c93(p1);
pm = c32(pm,mcol);
qm = c32(qm,mcol);
rm = c32(rm,mcol);
wm = c32(wm,mcol);
p2 = c28(pm,qm,rm,wm);
%
pull
return
