function [x] = carthes(r,phi)
%  CARTHES:  POLPAC function to convert polar to Carthesian coordinates
%
%  Usage:  x = carthes(r,phi)
%
%  This function transforms the lengths and phases of a
%  matrix back into Carthesian coordinates, and composes
%  them into a complex matrix.
%
%  This is the inverse function of POLAR.
%
%  Input Parameters:
%  -----------------
%
%    r      := Matrix of lengths
%    phi    := Matrix of phases (same size)
%
%  Output Parameter:
%  -----------------
%
%    x      := Matrix in Carthesian coordinates
%
push('CARTHES')
%
%  Check for consistency
%
[n1,m1] = size(r);
[n2,m2] = size(phi);
if n1 ~= n2,
  disp('CARTHES: Error - Incompatible rows'),
  abort,
end
if m1 ~= m2,
  disp('CARTHES: Error - Incompatible columns'),
  abort,
end
%  We need to loop over all columns separately, since COS and SIN
%  are transcendental functions which don't operate properly on
%  arbitrary matrices
%
for i=1:m1,
  re(:,i) = r(:,i).*cos(phi(:,i));
  im(:,i) = r(:,i).*sin(phi(:,i));
end
%
%  Concatenate
%
x = re + j*im;
%
pull
return
