function [p2] = cfs2rts(p1)
%  CFS2RTS:  POLPAC conversions coefficients -> roots
%
%  Usage:  p2 = cfs2rts(p1)
%
%  This function converts a POLPAC data structure stored in storage modes
%  1, 4, or 7 into a data structure stored in the equivalent storage mode
%  2, 5, or 8.
%
%  Input Parameter:
%  ----------------
%
%    p1     :=  POLPAC data structure (mode = 1, 4, or 7)
%
%  Output Parameter:
%  -----------------
%
%    p2     :=  Equivalent POLPAC data structure (mode = 2, 5, or 8)
%
push('CFS2RTS')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(p1(1,1));
mcl = (mode + 2)/3;
%
%  Check for consistency
%
if debg == 3,
  if abs(round(mcl) - mcl) > 1000*eps,
    disp('CFS2RTS: Error - Input must be in coefficient form'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 1,
  p2 = c12(p1);
  else if mode == 4,
    p2 = c45(p1);
    else
    p2 = c78(p1);
  end,
end
%
pull
return
