function [p2] = cfs2trj(p1,dom)
%  CFS2TRJ:  POLPAC conversions coefficients -> trajectoriess
%
%  Usage:  p2 = cfs2trj(p1,dom)
%
%  This function converts a POLPAC data structure stored in storage modes
%  1, 4, or 7 into a data structure stored in the equivalent storage mode
%  3, 6, or 9.
%
%  Input Parameter:
%  ----------------
%
%    p1     :=  POLPAC data structure (mode = 1, 4, or 7)
%
%  Output Parameter:
%  -----------------
%
%    p2     :=  Equivalent POLPAC data structure (mode = 3, 6, or 9)
%
push('CFS2TRJ')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(p1(1,1));
mcl = (mode + 2)/3;
%
%  Check for consistency
%
if debg == 3,
  if abs(round(mcl) - mcl) > 1000*eps,
    disp('CFS2TRJ: Error - Input must be in coefficient form'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 1,
  p2 = c13(p1,dom);
  else if mode == 4,
    p2 = c46(p1,dom);
    else
    p2 = c79(p1,dom);
  end,
end
%
pull
return
