function [gammac,p]=colpropt(pm)
% This function finds a unimodular matrix that makes pm column
% proper and its resultant Gamma matrix.
%
% ECE 544 Homewrok # 5 by Gyver Huang.
%
% Input Parameter:
% ----------------
%	pm	:= The polynomial matrix to be modified to column
%		   proper. ( mode 1 to 3 only)
% Output Parameters:
% ------------------
%	p	:= The unimodular transformation matrix that makes pm
%		   column proper.
%	gammac	:= Gamma matrix of the transformed column proper pm.
%
push('COLPROPT')
global debg
%
% unpacking the structure information.
[mode,logcol,dtype,stype]=unpack(pm(1,1));
[lrow,lcol]=logdim(pm);
[n,m]=size(pm);
dom=domain(pm);
%
% check for consistency.
if debg==3
	if (mode<1)|(mode>3)
		disp(' COLPROPT: Error -operates on mode 1 thru 3 only'),
		abort,
	end
end
%
% initialize p
p=eyep(lrow,lrow,mode,logcol,stype,dom);
%
% check if pm is already column proper, if so get Gamma and return
if iscolprop(pm)==1
	gammac=gamcol(pm);
else
	i=1;
	while (iscolprop(pm)==0)&(i<=lcol)
		[gammac,pm,p]=colpropti(pm,p,i);
		i=i+1;
	end
end
%
pull
return
