function [a] = companion(p)
%  COMPANION:  POLPAC function to compute lower companion matrix
%
%  Usage:  a = companion(p)
%
%  This function computes the lower companion matrix of a single
%  POLPAC polynomial.
%
%  Input Parameter:
%  ----------------
%
%    p      := Matlab single polynomial (represented by coefficients)
%
%  Output Parameter:
%  -----------------
%
%    a      := The lower companion matrix of the characteristic
%              polynomial p(s)
%
push('COMPANION')
global debg
%
%  Start by unpacking the structural information
%
pp = squeeze(p);
[mode,logcol,dtype,stype] = unpack(pp(1,1));
[lrow,lcol] = logdim(pp);
%
%  Check first for consistency
%
if debg == 3,
  if mode == 0,
    disp('COMPANION: Error - Operates on polynomials only'),
    abort,
  end,
  if mode > 3,
    disp('COMPANION: Error - Operates on polynomials only'),
    abort,
  end,
  if lrow*lcol ~= 1,
    disp('COMPANION: Error - Operates on single polynomials only'),
    abort,
  end,
  if logcol == 1,
    disp('COMPANION: Error - Does not operate on constants'),
    abort,
  end,
end
%
%  Now, check whether the polynomial is in mode 1, otherwise convert
%
if mode == 2,
  pp = c21(pp);
  else if mode == 3,
    pp = c31(pp,0);
  end,
end
%
%  Unpack the polynomial into Matlab representation
%
pp = oldpoly(pp);
[n,m] = size(pp);
%
%  Okay, now start packing into companion matrix
%
p1 = pp(1);
p2 = -pp(m:-1:2)/p1;
%
%  First order systems (m=2) require special treatment
%
if m == 2,
  a = p2;
  else
  m2 = m - 2;
  a = [ zeros(m2,1) , eye(m2) ; p2 ];
end
%
pull
return
