function [g3] = divp1(p1,p2)
%  DIVP1:  Divide two POLPAC polynomials
%
%  Usage:  g3 = divp1(p1,p2)
%
%  This function operates on single polynomials stored in modes 1 thru 3.
%  G3 is the division of P1 into P2.
%
%  Mixed mode operations are handled with a preference of trajectories
%  over coefficients over roots.
%
%  Input Parameters:
%  -----------------
%
%    p1     := Single polynomial in modes 1 thru 3
%    p2     := Single polynomial in modes 1 thru 3
%
%  Output Parameter:
%  -----------------
%
%    g3     := Single rational function in modes 4 thru 6
%
push('DIVP1')
global debg
%
%  Check for necessary conversions first
%
[pp1,pp2] = mixmod(p1,p2);
%
%  Start by unpacking the structural information
%
[mod1,lcol1,dtyp1,styp1] = unpack(pp1(1,1));
[mod2,lcol2,dtyp2,styp2] = unpack(pp2(1,1));
%
[n1,m1] = logdim(pp1);
[n2,m2] = logdim(pp2);
%
%  Check for consistency
%
if debg == 3,
  if mod1 < 1,
    disp('DIVP1: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
  if mod1 > 3,
    disp('DIVP1: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
  if styp2 ~= styp1,
    disp('DIVP1: Error - Incompatible system types'),
    abort,
  end,
end
if debg >= 2,
  if n1*m1 ~= 1,
    disp('DIVP1: Error - Operates on scalar polynomials only'),
    abort,
  end,
  if n2*m2 ~= 1,
    disp('DIVP1: Error - Operates on scalar polynomials only'),
    abort,
  end,
end
%
%  Perform the actual division now.
%
g3 = plm2tfm(pp1,pp2);
%
%  Do a final SQUEEZE.
%
g3 = squeeze(g3);
%
pull
return
