function [dom] = domain(pm)
%  DOMAIN:  Extract the domain information of POLPAC trajectory structure
%
%  Usage:  dom = domain(pm)
%
%  This function extracts the DOMAIN information from an existing
%  POLPAC data structure stored in modes 3, 6, or 9.  In all other
%  modes, DOMAIN simply returns 0.
%
%  DOM is a regular Matlab row vector.
%
%  Input Parameter:
%  ----------------
%
%    pm     : POLPAC data structure (mode 3, 6, or 9)
%
%  Output Parameter:
%  -----------------
%
%    dom    : Matlab row vector containing the DOMAIN information of PM.
%
push('DOMAIN')
%
%  Unpack structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
%
%  Check for appropriate mode
%
dom = 0;
if mode == 0,
  pull,
  return,
end
m3 = mode/3;
if abs(m3 - round(m3)) > 100*eps,
  pull,
  return,
end
%
%  Get the domain now
%
dom = pm(2,1:logcol);
%
pull
return
