function [g3] = elmultg(g1,g2)
%
%  This function operates on rational function matrices stored in
%  modes 4 thru 6.  G3 is the elementwise product of G1 and G2.
%
%  Mixed mode operations are handled with a preference of trajectories
%  over coefficients over roots.
%
%  Input Parameters:
%  -----------------
%
%    g1     := Rational function matrix in modes 4 thru 6
%    g2     := Rational function matrix in modes 4 thru 6
%
%  Output Parameter:
%  -----------------
%
%    g3     := Rational function matrix
%
push('ELMULTG')
global debg
%
%  Check for necessary conversions first
%
[gg1,gg2] = mixmod(g1,g2);
%
%  Start by unpacking the structural information
%
[mod1,lcol1,dtyp1,styp1] = unpack(gg1(1,1));
[mod2,lcol2,dtyp2,styp2] = unpack(gg2(1,1));
%
[n1,m1] = logdim(gg1);
[n2,m2] = logdim(gg2);
%
%  Check for consistency
%
if debg == 3,
  if mod1 < 4,
    disp('ELMULTG: Error - Operates only on modes 4 thru 6'),
    mod1,
    abort,
  end,
  if mod1 > 6,
    disp('ELMULTG: Error - Operates only on modes 4 thru 6'),
    mod1,
    abort,
  end,
  if styp2 ~= styp1,
    disp('ELMULTG: Error - Incompatible system types'),
    abort,
  end,
end
if debg >= 2,
  if n1 ~= n2,
    if m1 ~= m1,
      disp('ELMULTG: Error - Incompatible number of rows/columns'),
      abort,
    end,
  end,
end
%
%  Create a shell to store the result.
%
logcol = lcol1 + lcol2 - 1;
if mod1 == 6,
  logcol = lcol1;
end
dom1 = domain(pp1);
g3 = zerop(n1,m1,mod1,logcol,styp1,dom1);
%
%  Perform the actual multiplication now.
%
for i=1:n1,
  for k=1:m1,
    g1ik = gget(gg1,i,k);
    g2ik = gget(gg2,i,k);
    g3ik = multp1(g1ik,g2ik);
    g3 = put(g3,g3ik,i,k);
  end,
end
g3 = squeeze(g3);
%
pull
return
