function pp2 = evalp(pp1,svalue)
%  EVALP:   Evaluate polynomial matrix pp2 at s=svalue
%
%  Usage:  pp2 = evalp(pp1,svalue)
%
%  This function operates on polynomial matrices stored in modes 1 thru 3.
%  
%
%
%  Input Parameters:
%  -----------------
%
%    pp1        := Polynomial matrix in modes 1 thru 3
%    svalue     := complex number (imaginary part => frequency, real part =>
damping)
%
%  Output Parameter:
%  -----------------
%
%    pp2     := Polynomial matrix in modes 1 thru 3,   const =>
max(max(order(p2)))=0
%
push('EVALP')
global debg

%
%  Start by unpacking the structural information
%
[mod1,lcol1,dtyp1,styp1] = unpack(pp1(1,1));

%
%  Check for consistency
%
if debg == 3,
  if mod1 < 1,
    disp('EVALP: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
  if mod1 > 3,
    disp('EVALP: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
end

%
%  Check for necessary conversions first
%

if mod1 == 3

  modc = mod1;
  dom = domain(pp1);
  pp1 = c31(pp1);
  [mod1,lcol1,dtyp1,styp1] = unpack(pp1(1,1));

elseif mod1 == 2 
  modc = mod1;
  pp1 = c21(pp1);
  [mod1,lcol1,dtyp1,styp1] = unpack(pp1(1,1));
else
  modc=1;
end;

%
[n1,m1] = logdim(pp1);

%
%  Create a shell to store the result.
%
pp2 = zerop(n1,m1,mod1,lcol1,styp1,0);


%
%  Perform the actual evaluation now.
%  Loop over all polynomials.
%
for i=1:n1,
  for k=1:m1,
    p1ik = gget(pp1,i,k);
%     now for every polynomial
      [mod1ik,lcol1ik,dtyp1ik,styp1ik] = unpack(p1ik(1,1));      
      sum = 0; 
      pows = 1;  
      for l=1:lcol1ik
         sum = sum + p1ik(2,l) * pows;
         pows = pows * svalue;            % value of current svalue to the
power of (l-1)
      end
      ppsum(1,1) = ppack(mod1ik,1,dtyp1ik,styp1ik);      
      ppsum(2,1) = sum;
      pp2 = put(pp2,ppsum,i,k);
  end,
end

%
% now convert back into corresponding mode
%

if modc == 3

  pp2 = c13(pp2,dom);

elseif modc == 2 

  pp2 = c12(pp2);

else

% no conversion necessary

end;


%  Perform a SQUEEZE for the sake of it.
%
pp2 = squeeze(pp2);
%

pull

return
