function [gammac] = gamcol(pm)
%
%  This function computes the columnwise Gamma matrix of a polynomial
%  matrix.
%
%  Input Parameter:
%  ----------------
%
%    pm     := Any polynomial matrix (modes 1 thru 3)
%
%  Output Parameter:
%  -----------------
%
%    gammac := A scalar matrix whose elements in the ith column
%              consist of the coefficients of s^[ith column order]
%              of the polynomial matrix
%
push('GAMCOL')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
[nrow,ncol] = logdim(pm);
[n,m] = size(pm);
%
%  Check for consistency
%
if debg == 3,
  if mode == 0,
    disp('GAMCOL: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
  if mode > 3,
    disp('GAMCOL: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
end
%
%  If MODE=3, convert first into mode 2
%
pp = pm;
if mode == 3,
  pp = c32(pm,0);
  [mode,logcol,dtype,stype] = unpack(pp(1,1));
  [n,m] = size(pp);
end
%
%  Get the column orders
%
degree = order(pp);
deltac = max(degree);
%
%  If MODE=1, use the following algorithm
%
if mode == 1,
  for i=1:ncol,
    gammac(1:nrow,i) = pp(2:n,(i-1)*logcol+deltac(i)+1);
  end,
  pull,
  return,
end
%
%  Otherwise, it must be MODE=2
%
gain = pp(2:2:n-1,1:logcol:m-logcol+1);
for i=1:nrow,
  for k=1:ncol,
    if degree(i,k) == deltac(k),
      gammac(i,k) = gain(i,k);
      else
      gammac(i,k) = 0;
    end,
  end,
end
%
pull
return
