function [pm2] = gget(pm1,lrow,lcol)
%
%  This routine extracts the PM2 substructure from the PM1 data structure.
%  Storage modes 1 thru 6 are supported.
%
%  Input Parameters:
%  -----------------
%
%    pm1    : Given POLPAC data structure (modes 1 thru 6)
%    lrow   : vector containing the numbers of those rows that
%             are to be extracted (in ascending order)
%    lcol   : vector containing the numbers of those columns that
%             are to be extracted (in ascending order)
%
%  Output Parameter:
%  -----------------
%
%    pm2    : Extracted POLPAC data structure (same mode as PM1)
%
push('GGET')
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm1(1,1));
%
%  No need to check for consistency since this happens
%  automatically inside PMAP.
%
%  Get the physical addresses, and extract the submatrix
%
[prow,pcol] = pmap(pm1,lrow,lcol);
pm = pm1(prow,pcol);
%
%  Pack into new data structure
%
[n,m] = size(pm);
dtype = datatype(pm);
nbr = ppack(mode,logcol,dtype,stype);
pm2 = [ nbr , zeros(1,m-1) ];
if mode == 3,
  pm2 = [ pm2 ; zeros(1,m) ];
  pm2(2,1:logcol) = pm1(2,1:logcol);
end
if mode == 6,
  pm2 = [ pm2 ; zeros(1,m) ];
  pm2(2,1:logcol) = pm1(2,1:logcol);
end
pm2 = [ pm2 ; pm ];
%
%  SQUEEZE the data structure to reduce to minimal size
%
pm2 = squeeze(pm2);
%
pull
return
