function [gm2] = invg(gm1)
%
%  This function inverts a rational function matrix.
%
%  Input Parameter:
%  ----------------
%
%    gm1    :=  The rational function matrix to be inverted
%               (modes 4, 5, or 6 only)
%
%  Output Parameter:
%  -----------------
%
%    gm2    :=  The inverse matrix, usually rational, but can be polynomial
%
push('INVG');
global debg
%
%  Start by unpacking the structural information.
%
[mode,logcol,dtype,stype] = unpack(gm1(1,1));
%
%  Check for consistency.
%
if debg == 3,
  if mode < 4,
    disp('INVG: Error - Operates on modes 4 thru 6 only'),
    abort,
  end,
  if mode > 6,
    disp('INVG: Error - Operates on modes 4 thru 6 only'),
    abort,
  end,
end
%
%  Find the common denominator.
%
[pm,cdp] = commonden(gm1);
%
%  Invert the polynomial matrix PM
%
gm2 = mult(cdp,invp(pm));
%
pull
return
