function [flag] = iscolprop(pm)
%
%  This function determines whether ot not the polynomial matrix
%  PM is column-proper.
%
%  Input Parameter:
%  ----------------
%
%    pm     := Any polynomial matrix (modes 1 thru 3)
%
%  Output Parameter:
%  -----------------
%
%    flag   := A scalar flag
%               := 0 (false)  :  The polynomial matrix is not column-proper
%               := 1 (true)   :  The polynomial matrix is column-proper
%
push('ISCOLPROP')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode == 0,
    disp('ISCOLPROP: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
  if mode > 3,
    disp('ISCOLPROP: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
end
%
%  Get the column gamma matrix
%
gammac = gamcol(pm);
[nrow,ncol] = size(gammac);
%
%  Determine whether it is column proper
%
flag = 1;
n = min([nrow,ncol]);
nn = rank(gammac);
if nn < n,
  flag = 0;
end
%
pull
return
