function [flag] = isrowprop(pm)
%
%  This function determines whether ot not the polynomial matrix
%  PM is row-proper.
%
%  Input Parameter:
%  ----------------
%
%    pm     := Any polynomial matrix (modes 1 thru 3)
%
%  Output Parameter:
%  -----------------
%
%    flag   := A scalar flag
%               := 0 (false)  :  The polynomial matrix is not row-proper
%               := 1 (true)   :  The polynomial matrix is row-proper
%
push('ISROWPROP')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode == 0,
    disp('ISROWPROP: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
  if mode > 3,
    disp('ISROWPROP: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
end
%
%  Get the row gamma matrix
%
gammar = gamrow(pm);
[nrow,ncol] = size(gammar);
%
%  Determine whether it is row proper
%
flag = 1;
n = min([nrow,ncol]);
nn = rank(gammar);
if nn < n,
  flag = 0;
end
%
pull
return
