function [s3] = ldiv(s1,s2)
%
%  This function divides two POLPAC data structures s1 and s2.
%
%  Input Parameters:
%  -----------------
%
%    s1     := POLPAC data structure (modes 1..6)
%    s2     := POLPAC data structure (modes 1..6)
%
%  Output Parameters:
%  ------------------
%
%    s3     := POLPAC data structure
%
push('LDIV')
%
%  Check for mixed mode operations
%
[s1,s2] = mixmod(s1,s2);
%
%  Start by unpacking the structural information
%
[mod1,lcol1,dtyp1,styp1] = unpack(s1(1,1));
[mod2,lcol2,dtyp2,styp2] = unpack(s2(1,1));
%
%  Determine the mode classes
%
mc1 = round((mod1 + 1)/3);
mc2 = round((mod2 + 1)/3);
%
%  The two data structures may not be in different mode classes.
%
if mc1 ~= mc2,
  disp('LDIV: Error - Incompatible data structures'),
  abort,
end
%
%  The mode classes are the same.
%  Branch according to the mode class.
%
if mc1 == 1,
  s3 = ldivp(s1,s2);
  else if mc1 == 2,
    s3 = ldivg(s1,s2);
  end,
end
%
pull
return
