function [s2] = minreals(s1)
%
%  This function transforms an either continuous or discrete
%  system representation in the time domain (POLPAC mode = 0)
%  into a minimal system representation using the staircase algorithm.
%
%  Input Parameter:
%  -----------------
%
%    s1   := POLPAC stable system representation in time domain (mode 0).
%
%  Output Parameters:
%  -----------------
%
%    s2   := Minimal POLPAC representation in the time domain (mode 0).
%
push('MINREALS')
global debg
%
%  Start by unpacking the structural information of the input matrix s1.
%
[mode,logcol,dtype,stype] = unpack(s1(1,1));
%
%  Check for consistency.
%
if debg == 3,
  if mode ~= 0,
    disp('MINREALS: Error - The algorithm works only in MODE = 0')
    abort,
    return,
  end,
end
%
%  Extract the A, B, C and D matrices from S1.
%
[A,B,C,D] = oldsyst(s1);
[Amin,Bmin,Cmin,Dmin] = minreal2(A,B,C,D);
s2 = newsyst(Amin,Bmin,Cmin,Dmin,stype);
%
pull
return
