function [l2,m2,indx] = mroot(l1,m1)
%
%  This function computes the multiplicity of eigenvalues. It has
%  three differenty algorithms to perform this. The choice of the 
%  algorithm depends upon the global variable MRTFLAG.
%
%  if MRTFLAG==0, MROOT0 algorithm is used.
%  if MRTFLAG==1, MROOT1 algorithm is used, itself using NEIG1.
%  if MRTFLAG==2, MROOT2 algorithm is used, itself using NEIG2.
%
%
%
%  Input Parameters:
%  -----------------
%
%    l1     := A set of roots (column vector)
%    m1     := Column vector of their multiplicities
%
%  Output Parameters:
%  ------------------
%
%    l2     := Column vector of sorted distinct eigenvalues
%    m2     := Column vector of their multiplicities
%    indx   := Index column vector relating the input vector
%              to the output vector
%
push('MROOT')
global debg
global mrtflag
%
[n,m] = size(l1);
%
%  Check for consistency
%
if debg == 3,
  if mrtflag ~= 0,
    if mrtflag ~= 1,
      if mrtflag ~= 2,
        disp('MROOT: Error - MRTFLAG must be 0, 1, or 2.'),
        abort,
      end,
    end,
  end,
end
%
%  Jump to one of the algorithms.
%
if mrtflag == 0, [l2,m2,indx] = mroot0(l1,m1); end
if mrtflag == 1, [l2,m2,indx] = mroot1(l1,m1); end
if mrtflag == 2, [l2,m2,indx] = mroot2(l1,m1); end
%
pull
return
