function [l,m,indx] = mroot1(l1,m1)
%
%  This function computes the multiplicities of roots using the
%  NEIGAL1 algorithm.
%
%  Input Parameter:
%  ----------------
%
%    l1     := Input eigenvalues
%    m1     := Multiplicities
%
%  Output parameters:
%  ------------------
%
%    l      := column vector of distinct eigenvalues
%    m      := column vector of their multiplicities
%    indx   := index column vector relating the input vector to
%              the output vector
%
push('MROOT1')
global debg
[n,nn] = size(l1);
%
%  Check for consistency
%
if debg == 3,
  [nn,mm] = size(m1);
  if m ~= 1,
    disp('MROOT1: Error - The input must be a column vector'),
    abort,
  end,
  if mm ~= 1,
    disp('MROOT1: Error - The input must be a column vector'),
    abort,
  end,
  if n ~= nn,
    disp('MROOT1: Error - The input vectors are incompatible'),
    abort,
  end,
end
%
%  Get the companion matrix
%
ll = 0;
for ii=1:n,
  for jj=1:m1(ii),
    ll = [ ll ; l1(ii) ];
  end,
end
[n1,nn] = size(ll);
ll = ll(2:n1);
p = poly(ll);
r = newpoly(p',1);
a = companion(r);
[l,m,index] = neigal1(a,ll);
%
indx = 0;
i = 1;
for ii=1:n,
  indx = [ indx ; index(i) ];
  i = i + m1(ii);
end
[n,nn] = size(indx);
indx = indx(2:n);
%
pull
return
