function [s3] = mult(s1,s2)
%
%  This function multiplies two POLPAC data structures s1 and s2.
%
%  Input Parameters:
%  -----------------
%
%    s1     := POLPAC data structure (any mode)
%    s2     := POLPAC data structure (any mode)
%
%  Output Parameters:
%  ------------------
%
%    s3     := POLPAC data structure (any mode)
%
push('MULT')
%
%  Check for mixed mode operations
%
[s1,s2] = mixmod(s1,s2);
%
%  Start by unpacking the structural information
%
[mod1,lcol1,dtyp1,styp1] = unpack(s1(1,1));
[mod2,lcol2,dtyp2,styp2] = unpack(s2(1,1));
%
%  Determine the mode classes
%
mc1 = round((mod1 + 1)/3);
mc2 = round((mod2 + 1)/3);
%
%  If the two data structures are still in different mode classes (in spite
%  of MIXMOD having been applied earlier), we probably want to perform a
%  simulation.
%
if mc1 ~= mc2,
  disp('MULT: Error - Simulation has not yet been implemented'),
  abort,
end
%
%  The mode classes are the same.
%  Branch according to the mode class.
%
if mc1 == 0,
  s3 = mults(s1,s2);
  else if mc1 == 1,
    s3 = multp(s1,s2);
    else if mc1 == 2,
      s3 = multg(s1,s2);
      else
        s3 = multps(s1,s2);
      end,
    end,
  end,
end
%
pull
return
