function [mu] = munorm(a)
%
%  Compute the mu-norm of a square matrix A.  The mu-norm is the largest
%  singular value of D*A/D, where D is any suitable scaling matrix.
%
%  Input Parameter:
%  ----------------
%
%    A      :=  square Matlab matrix
%
%  Output Parameter:
%  -----------------
%
%    muval  :=  mu-norm of A
%
push('MUNORM')
global debg
%
[n,m] = size(a);
if debg == 3,
  if n ~= m,
    disp('MUNORM: Error - Mu-norm only defined for square matrices'),
    abort,
    return,
  end,
end
%
%  Compute the optimal scaling matrix
%
d2 = ones(n,1);
d2new = ones(n,1);
aa = abs(a);
aa = aa .* aa;
er = 1000;
while er > 1.0e-6,
  ai = aa(2:n,1) .* d2(2:n);
  aj = aa(1,2:n) ./ d2(2:n)';
  d2new(1) = sqrt(sum(ai)/sum(aj));
  for k=2:n-1,
    ai = aa([1:k-1,k+1:n],k) .* d2([1:k-1,k+1:n]);
    aj = aa(k,[1:k-1,k+1:n]) ./ d2([1:k-1,k+1:n])';
    d2new(k) = sqrt(sum(ai)/sum(aj));
  end,
  er = norm(d2new - d2);
  d2 = d2new;
end
d = sqrt(d2);
d = diag(d);
aa = d*a/d;
s = svd(aa);
mu = s(1);
pull
return
