function [pm] = newmat(a,mode,stype,dom)
%
%  This function converts a Matlab matrix A to a polynomial
%  matrix PM of zeroth order stored in modes 1 thru 3.
%
%  Input Parameters:
%  -----------------
%   
%    a      := Any Matlab matrix
%    mode   := Desired output mode of PM
%    stype  := Desired output system type of PM
%    dom    := Desired base values in case desired mode of PM is 3
%
%  Output Parameter:
%  -----------------
%
%    pm     := Polynomial matrix in modes 1 thru 3.
%
push('NEWMAT')
global debg
%
%  Check whether the output mode is valid.
%
if debg == 3,
  if mode < 1,
    disp('NEWMAT: Error - Operates only on modes 1 thru 3'),
    mode,
    abort,
  end,
  if mode > 3,
    disp('NEWMAT: Error - Operates only on modes 1 thru 3'),
    mode,
    abort,
  end,
end
%
%  The system type will be checked by the routines PACK and ZEROP.
%
%  Get the physical dimensions of A.
%
[ra,ca] = size(a);
%
%  Compute the TYPE of A.
%
dtype = datatype(a);
%
%  Proceed to convert A to PM depending on the mode.
%
if mode == 1,
  nbr = ppack(mode,1,dtype,stype);
  pm = [nbr,zeros(1,ca-1);a];
  else if mode == 2,
    pm = zerop(ra,ca,mode,1,stype,0);
    nbr = ppack(mode,1,dtype,stype);
    pm(1,1) = nbr;
    pm(2:2:2*ra,1:ca) = a;
    else
      [rd,lgc] = size(dom);
      dtype = max([datatype(dom);dtype]);
      pm = zerop(ra,ca,mode,lgc,stype,dom);
      nbr = ppack(mode,lgc,dtype,stype);
      pm(1,1) = nbr;
      for i = 1:ca,
        pm(3:ra+2,(i-1)*lgc+1:i*lgc) = a(:,i)*ones(1,lgc);
      end,
    end,
  end,
end     
%
pull
return
