function [a] = oldmat(pm)
%
%  This function converts a polynomial matrix PM of zero order
%  stored in modes 1 thru 3 to a Matlab matrix A. if PM is not of 
%  zero order, an error message will be issued under DEBG>=2 setting.
%
%  Input Parameter:
%  ----------------
%   
%    pm     := Polynomial matrix in modes 1 thru 3.
%
%  Output Parameter:
%  -----------------
%
%    a      := Matlab matrix.
%
push('OLDMAT')
global debg
%
%  First of all squeeze!
%
pm = squeeze(pm);
%
%  Start by unpacking the structural information.
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
%
%  Check whether PM is of valid mode and of zero order.
%
if debg == 3,
  if mode < 1,
    disp('OLDMAT: Error - Operates only on modes 1 thru 3'),
    mode,
    abort,
  end,
  if mode > 3,
    disp('OLDMAT: Error - Operates only on modes 1 thru 3'),
    mode,
    abort,
  end,
end
if debg >= 2,
  if mode ~= 3,
    if logcol ~= 1,
      t1 = 'OLDMAT: Error - PM must be a zero order';
      t2 = '                polynomial matrix      ';
      t1 = [t1;t2];
      disp(t1),
      logcol,
      abort,
    end,
  end,
  if mode == 3,
    %
    %  Extract polynomials and check whether their order is zero.
    %  A polynomial is of zero order if the evaluations over the
    %  base values are all the same.
    %
    [lr,lc] = logdim(pm);
    for i=1:lr,
      for k=1:lc,
        k1 = (k - 1)*logcol + 1;
        k2 = k*logcol;
        pol = pm(2+lr,k1:k2);
        pm1 = pm(2+lr,k1)*ones(1,logcol);
        if norm(pol - pm1,'inf') > 1000*eps,
          t1 = 'OLDMAT: Error - PM must be a zero order';
          t2 = '                polynomial matrix      ';
          t1 = [t1;t2];
          disp(t1),
          abort,
        end,
      end,
    end,
  end,
end
%
%  Extract the Matlab matrix A depending on the mode of PM.
%  We need the physical dimension of PM.
%
[rp,cp] = size(pm);
%
if mode == 1,
  a = pm(2:rp,1:cp);
  else if mode == 2,
    a = pm(2:2:rp-1,1:cp);
    else
    a = pm(3:rp,1:logcol:cp-logcol+1);
  end,
end
%
pull
return
