function [p] = oldpoly(pm)
%
%  This function extracts a single Matlab polynomial from a POLPAC
%  polynomial.
%
%  If the storage mode = 1, POLPAC returns the coefficients as
%  a row vector as expected by Matlab (i.e. in descending order).
%
%  If the storage mode = 2, POLPAC returns the roots as a column
%  vector as expected by Matlab (i.e. multiple roots are listed
%  several times).  The gain factor is lost.
%
%  Input Parameters:
%  -----------------
%
%    pm     := Polynomial matrix (POLPAC mode = 1 or 2)
%
%  Output Parameter:
%  -----------------
%
%    p      := Matlab polynomial
%                mode = 1:  coefficients in descending order (row vector)
%                mode = 2:  roots in arbitrary order (column vector)
%
push('OLDPOLY')
global debg
%
%  First squeeze!
%
pm = squeeze(pm);
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
[n,m] = logdim(pm);
%
%  Check for consistency
%
if debg == 3,
  if mode ~= 1,
    if mode ~= 2,
      disp('OLDPOLY: Error - MODE must be either 1 or 2'),
      mode,
      abort,
    end,
  end,
  if n*m ~= 1,
    disp('OLDPOLY: Error, Operates only on single polynomials'),
    abort,
  end,
end
%
%  For the sake of it, SQUEEZE
%
pm2 = squeeze(pm);
[mode,logcol,dtype,stype] = unpack(pm2(1,1));
%
%  Treat each mode separately
%
%  First case: mode = 1
%
if mode == 1,
  p = pm2(2,logcol:-1:1);
end
%
%  Second case:  mode = 2
%
if mode == 2,
  if logcol == 1,
    disp('OLDPOLY: Error - This polynomial has no roots'),
    abort,
  end,
  p = 0;
  for i=2:logcol,
    p = [ p ; pm2(2,i)*ones(pm2(3,i),1) ];
  end,
  [n,m] = size(p);
  p = p(2:n);
end
%
pull
return
