function [a,b,c,d] = oldsyst(s)
%
%  This function extracts the four system matrices A, B, C, and D
%  from a POLPAC system in time domain representation (storage mode 0).
%
%  Input Parameter:
%  ----------------
%
%    s      := System matrix (POLPAC mode = 0)
%
%  Output Parameters:
%  ------------------
%
%    a      := State matrix
%    b      := Input matrix
%    c      := Output matrix
%    d      := Input-output matrix
%
push('OLDSYST')
global debg
%
%  We first check whether MODE is legal.
%
if debg == 3,
  %
  %  Unpack the structural information
  %
  [mode,logcol,dtype,stype] = unpack(s(1,1));
  if mode ~= 0,
    disp('OLDSYST: Error - MODE must be 0'),
    mode,
    abort,
  end,
end
%
%  Get dimensions now
%
[np,nm] = size(s);
if nm == 1,
  n = 0;
  else
  n = s(1,2);
end
%
%  First take care of the case of a constant system
%
if n == 0,
  a = [];
  b = [];
  c = [];
  d = s(2:np,1:nm);
  pull,
  return,
end
%
%  Now check the regular case
%
m = nm - n;
p = np - n - 1;
%
%  Check structural compatibility
%
if debg >= 2,
  if m < 1,
    disp('OLDSYST: Error - System order inconsistent with data'),
    abort,
  end,
  if p < 1,
    disp('OLDSYST: Error - System order inconsistent with data'),
    abort,
  end,
end
%
%  Perform actual extraction
%
n1 = n + 1;
n2 = n + 2;
a = s(2:n1,1:n);
b = s(2:n1,n1:nm);
c = s(n2:np,1:n);
d = s(n2:np,n1:nm);
%
pull
return
