function [degree] = order(pm)
%
%  This POLPAC function computes a matrix of polynomial orders of
%  a polynomial matrix in any of the three modes 1 thru 3
%
%  Input Parameter:
%  ----------------
%
%    pm     := A polynomial matrix (modes 1 thru 3)
%
%  Output Parameter:
%  -----------------
%
%    degree := A Matlab matrix containing the individual polynomial orders
%
push('ORDER')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
[nrow,ncol] = logdim(pm);
%
%  Check for consistency
%
if debg == 3,
  if mode == 0,
    disp('ORDER: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
  if mode > 3,
    disp('ORDER: Error - Operates only on modes 1 thru 3'),
    abort,
  end,
end
%
%  If mode = 3, convert first into mode 1
%
pp = pm;
if mode == 3,
  pp = c31(pm,0);
  [mode,logcol,dtype,stype] = unpack(pp(1,1));
end
%
%  If mode = 1, use the following algorithm
%
if mode == 1,
  for i=1:nrow,
    for k=1:ncol,
      p = gget(pp,i,k);
      [m,l,d,s] = unpack(p(1,1));
      degree(i,k) = l - 1;
    end,
  end,
  pull,
  return,
end
%
%  Otherwise, it must be mode = 2
%
[n,m] = size(pp);
degree = pp(3:2:n,1:logcol:m-logcol+1);
%
pull
return
