function [gm] = plm2tfm(pm,qm)
%
%  This function converts two polynomial matrices (stored in
%  storage modes 1 thru 3) into a single transfer function matrix
%  (stored in the corresponding storage mode 4 thru 6).
%
%  Input Parameters:
%  -----------------
%
%    pm     := Numerator polynomial matrix (mode = 1 thru 3)
%    qm     := Denominator polynomial matrix (mode = 1 thru 3)
%
%  Output Parameter:
%  -----------------
%
%    gm     := Transfer function matrix (mode = 4 thru 6)
%
push('PLM2TFM')
global debg
%
%  Start by using mixmod
%
[pm,qm] = mixmod(pm,qm);
%
%  Unpack the structural information
%
[mod1,logco1,dtyp1,styp1] = unpack(pm(1,1));
[mod2,logco2,dtyp2,styp2] = unpack(qm(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mod1 < 1,
    disp('PLM2TFM: Error - Inputs must be polynomial matrices'),
    abort,
  end,
  if mod1 > 3,
    disp('PLM2TFM: Error - Inputs must be polynomial matrices'),
    abort,
  end,
  if mod1 < 1,
    disp('PLM2TFM: Error - Inputs must be polynomial matrices'),
    abort,
  end,
  if mod1 > 3,
    disp('PLM2TFM: Error - Inputs must be polynomial matrices'),
    abort,
  end,
  if styp1 ~= styp2,
    disp('PLM2TFM: Error - STYPE of PM ~= STYPE of QM'),
    abort,
  end,
end
if debg >= 2,
  [m1,n1] = logdim(pm);
  [m2,n2] = logdim(qm);
  if m1 ~= m2,
    disp('PLM2TFM: Error - Logical rows are incompatible'),
    abort,
  end,
  if n1 ~= n2,
    disp('PLM2TFM: Error - Logical columns are incompatible'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mod1 == 1,
  gm = c14(pm,qm);
  else if mod1 == 2,
    gm = c25(pm,qm);
    else
    gm = c36(pm,qm);
  end,
end
%
pull
return
