function [pm,qm,rm,wm] = pms2plm(pms)
%
%  This function converts a polynomial matrix system description
%  (stored in storage modes 7 thru 9) into a set of four polynomial
%  matrices (stored in the corresponding storage modes 1 thru 3).
%
%  Input Parameter:
%  ----------------
%
%    pms    := Polynomial matrix system description (mode = 7 thru 9)
%
%  Output Parameters:
%  -----------------
%
%    pm     := System polynomial matrix (mode = 1 thru 3)
%    qm     := Input polynomial matrix (mode = 1 thru 3)
%    rm     := Output polynomial matrix (mode = 1 thru 3)
%    wm     := Direct coupling polynomial matrix (mode = 1 thru 3)
%
push('PMS2PLM')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pms(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode < 7,
    disp('PMS2PLM: Error - Input must be polynomial matrix system'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 7,
  [pm,qm,rm,wm] = c71(pms);
  else if mode == 8,
    [pm,qm,rm,wm] = c82(pms);
    else
    [pm,qm,rm,wm] = c93(pms);
  end,
end
%
pull
return
