function [s] = pms2ss(pms)
%
%  This function converts a polynomial matrix system description
%  (stored in storage modes 7 thru 9) into a state-space description
%  (stored in mode 0).
%
%  Input Parameter:
%  ----------------
%
%    pms    := Polynomial matrix system description (mode = 7 thru 9)
%
%  Output Parameter:
%  -----------------
%
%    s      := State-space description (mode = 0)
%
push('PMS2SS')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pms(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode < 7,
    disp('PMS2SS: Error - Input must be polynomial matrix system'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 7,
  s = c70(pms);
  else if mode == 8,
    s = c80(pms);
    else
    s = c90(pms);
  end,
end
%
pull
return
