function [gm] = pms2tfm(pms)
%
%  This function converts a polynomial matrix system description
%  (stored in storage modes 7 thru 9) into a transfer function matrix
%  (stored in the corresponding storage mode 4 thru 6).
%
%  Input Parameter:
%  ----------------
%
%    pms    := Polynomial matrix system description (mode = 7 thru 9)
%
%  Output Parameter:
%  -----------------
%
%    gm     := Transfer function matrix (mode = 4 thru 6)
%
push('PMS2TFM')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pms(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode < 7,
    disp('PMS2TFM: Error - Input must be polynomial matrix system'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 7,
  gm = c74(pms);
  else if mode == 8,
    gm = c85(pms);
    else
    gm = c96(pms);
  end,
end
%
pull
return
