function [] = polpac_mode0()
%
%  Linear system in time domain:
%  -----------------------------
%
%  A linear continuous-time multivariable system:
%
%            x. = A*x + B*u
%            y  = C*x + D*u
%
%  with m inputs, p outputs and n states is structurally completely
%  specified through the four matrices:
%
%            A   (dimension: nxn)
%            B   (dimension: nxm)
%            C   (dimension: pxn)
%            D   (dimension: pxm)
%
%  These can conveniently be fitted together to form the system "matrix":
%
%            S = [ A , B
%                  C , D ]
%
%  The system is uniquely characterized by the S-matrix together with
%  information about the system order (n).  In POLPAC, we make use of
%  this representation (storage mode 0) by coding the additionally
%  needed information into a top row:
%
%            S = [ nbr , n , do_not_care
%                  A , B
%                  C , D                 ]
%
%  where nbr contains the information about the storage mode:
%
%            nbr = 1000*logcol + 100*mode + 30*stype +10*dtype + version
%
%  The same representation can be used for the linear discrete-time
%  system:
%
%            x(k+1) = F*x(k) + G*u(k)
%            y(k)   = H*x(k) + I*u(k)
%
%  where:
%
%            S = [ nbr , n , do_not_care
%                  F , G
%                  H , I                 ]
%
%  This is distinguished from the continuous case by the STYPE parameter
%  (encoded in NBR) which is now 1 instead of 0.
%
%  Example:
%  --------
%
%                  [  0  1  0  0  0          [ 1  0
%            .        0  0  1  0  0            0  0
%            x   =    0  0  0  1  0   x  +     0  0   u
%            -        0  0  0  0  1   -        0  0   -
%                    -2 -3 -4 -5 -6 ]          0  1 ]
%
%                  [  1  1 -1  2  5          [ 0  0
%            y   =    1 -1  2  0  0   x  +     0  1   u
%            -        0  0  0  1 -1 ] -        0  0 ] -
%
%  has:   n = 5  ;  m = 2  ;  p = 3
%
%         logcol  = 1 (always)
%         mode    = 0
%         stype   = 0
%         dtype   = 1
%         version = 1 (currently)
%
%            ==> nbr = 1011
%
%  Thus, this system can be represented through the matrix:
%
%         S = [ 1011    5    0    0    0    0    0
%                  0    1    0    0    0    1    0
%                  0    0    1    0    0    0    0
%                  0    0    0    1    0    0    0
%                  0    0    0    0    1    0    0
%                 -2   -3   -4   -5   -6    0    1
%                  1    1   -1    2    5    0    0
%                  1   -1    2    0    0    0    1
%                  0    0    0    1   -1    0    0 ]
%
return
