function [] = polpac_mode1()
%
%  Polynomial matrix (represented through coefficients):
%  -----------------------------------------------------
%
%  Polynomial matrices are useful in several types of system description.
%  Notice, however, that polynomial matrices are just mathematical data
%  structures (similar to matrices and vectors), and not by themselves
%  system descriptions.
%
%  POLPAC supports the notion of polynomial matrices.  The top row of the
%  data structure contains coded information about the storage mode, the
%  highest order of the polynomials in the matrix, etc., thus:
%
%             P(s) = [ nbr , do_not_care
%                      P11(s) , P12(s) , ... , P1m(s)
%                      ...      ...            ...
%                      Pp1(s) , Pp2(s) , ... , Ppm(s) ]
%
%  denotes a polynomial matrix with m logical columns and p logical rows.
%
%  The variable LOGCOL (encoded in NBR)
%
%         nbr = 1000*logcol + 100*mode + 30*stype + 10*dtype + version
%
%  determines the number of physical columns making up one logical column.
%
%  Example:
%  --------
%
%  Given the polynomial matrix:
%
%             P(s) = [ (8s^2+5s+7)      0       (2s-5)
%                          s^3       (s^2-10)      1   ]
%
%  has:  logcol  = 4  (highest order + 1)
%        mode    = 1
%        stype   = 0
%        dtype   = 1
%        version = 1  (currently)
%           ==> nbr = 4111
%
%  It can thus be represented as:
%
%             P = [ 4111   0   0   0   0   0   0   0   0   0   0   0
%                      7   5   8   0   0   0   0   0  -5   2   0   0
%                      0   0   0   1 -10   0   1   0   1   0   0   0 ]
%
return
