function [] = polpac_mode2()
%
%  Polynomial matrix (represented through roots):
%  ----------------------------------------------
%
%  Polynomial matrices are useful in several types of system description.
%  Notice, however, that polynomial matrices are just mathematical data
%  structures (similar to matrices and vectors), and not by themselves
%  system descriptions.
%
%  POLPAC supports the notion of polynomial matrices.  The top row of the
%  data structure contains coded information about the storage mode, the
%  highest order of the polynomials in the matrix, etc., thus:
%
%             P(s) = [ nbr , do_not_care
%                      P11(s) , P12(s) , ... , P1m(s)
%                      ...      ...            ...
%                      Pp1(s) , Pp2(s) , ... , Ppm(s) ]
%
%  denotes a polynomial matrix with m logical columns and p logical rows.
%
%  Each individual polynomial is described through 2 physical rows, the upper
%  describing the gain factor and the roots, the lower describing the total
%  order, and the multiplicities of the roots, thus:
%
%                      P(s) = 5(s+10)(s+4)(s+4)
%
%  can be described as:
%
%                      P = [ 5 -10  -4     or:    P = [ 5  -4 -10
%                            3   1   2 ]                3   2   1 ]
%
%  The variable LOGCOL (encoded in NBR)
%
%          nbr = 1000*logcol + 100*mode + 30*stype + 10*dtype + version
%
%  determines the number of physical columns making up one logical column.
%
%  Example:
%  --------
%
%  Given the polynomial matrix:
%
%             P(s) = [ 10(s+1)^2         0         (s+2)(s+3)
%                         s^3     5(s+10)(s+4)^2        1     ]
%
%  has:  logcol  = 4  (highest order + 1)
%        mode    = 2
%        stype   = 0
%        dtype   = 1
%        version = 1  (currently)
%           ==> nbr = 4211
%
%  It can thus be represented as:
%
%             P = [ 4211   0   0   0   0   0   0   0   0   0   0   0
%                     10  -1   0   0   0   0   0   0   1  -2  -3   0
%                      2   2   0   0   0   0   0   0   2   1   1   0
%                      1   0   0   0   5 -10  -4   0   1   0   0   0
%                      3   3   0   0   3   1   2   0   0   0   0   0 ]
%
return
