function [] = polpac_mode3()
%
%  Polynomial matrix (represented through trajectories):
%  -----------------------------------------------------
%
%  Polynomial matrices are useful in several types of system description.
%  Notice, however, that polynomial matrices are just mathematical data
%  structures (similar to matrices and vectors), and not by themselves
%  system descriptions.
%
%  POLPAC supports the notion of polynomial matrices.  The top row of the
%  data structure contains coded information about the storage mode, the
%  highest order of the polynomials in the matrix, etc.  The second row
%  contains the DOMAIN information, i.e. the base of si-values over which
%  all trajectories are spanned, thus:
%
%             P(s) = [ nbr , do_not_care
%                      domain , do_not_care
%                      P11(s) , P12(s) , ... , P1m(s)
%                      ...      ...            ...
%                      Pp1(s) , Pp2(s) , ... , Ppm(s) ]
%
%  denotes a polynomial matrix with m logical columns and p logical rows.
%  Each Pjk(s) contains the values of Pjk evaluated at the domain values si.
%
%  The variable LOGCOL (encoded in NBR)
%
%          nbr = 1000*logcol + 100*mode + 30*stype + 10*dtype + version
%
%  determines the number of physical columns making up one logical column.
%
%  The same data structure is also useful to denote trajectory matrices
%  which now have a physical interpretation.  The domain denotes here the set
%  of supporting values for the trajectories stored in the trajectory matrix.
%
%  Example:
%  --------
%
%  Given the polynomial matrix:
%
%             P(s) = [ (8s^2+5s+7)      0       (2s-5)
%                          s^3       (s^2-10)      1   ]
%
%  spanned over the DOMAIN: [ +1 , +j , -1 , -j ]
%
%  We can evaluate these polynomials at the base values, and find:
%
%               s  |  P11(s)  P12(s)  P13(s)  P21(s)  P22(s)  P23(s)
%             -----+--------------------------------------------------
%              +1  |   20       0      -3       1      -9       1
%              +j  |   -1+5j    0      -5+2j    0-j   -11       1
%              -1  |   10       0      -7      -1      -9       1
%              -j  |   -1-5j    0      -5-2j    0+j   -11       1
%
%  has:  logcol  = 4  (number of base values)
%        mode    = 3
%        stype   = 0
%        dtype   = 3
%        version = 1  (currently)
%           ==> nbr = 4331
%
%  It can thus be represented as:
%
%        P = [ 4331     0   0     0   0   0   0   0   0     0   0     0
%                 1     j  -1    -j   0   0   0   0   0     0   0     0
%                20 -1+5j  10 -1-5j   0   0   0   0  -3 -5+2j  -7 -5-2j
%                 1    -j  -1     j  -9 -11  -9 -11   1     1   1     1 ]
%
return
