function [] = polpac_mode5()
%
%  Transfer function matrix (represented through roots):
%  -----------------------------------------------------
%
%  Transfer function matrices are one way to describe linear systems in the
%  frequency domain.  POLPAC uses the same methodology as for polynomial
%  matrices to represent transfer function matrices.  Thereby, the
%  numerator polynomial matrix is simply concatenated from below by the
%  denominator polynomial matrix.  The same data structure can be used to
%  represent both continuous-time systems (G(s)) using the Laplace transform
%  (STYPE=0) and discrete-time systems (G(z)) using the z-transform (STYPE=1).
%
%  Storage mode 5 corresponds to storage mode 2.
%
%  Example:
%  --------
%
%  Given the transfer function matrix:
%
%                      10(s+1)^2                   (s+2)(s+3)
%             G(s) = [ ---------         0         ----------
%                         s^3                       (s+1)^2
%
%                          5          7(s-10)
%                         ---     --------------       1     ]
%                         s^3     5(s+10)(s+4)^2
%
%  has:  logcol  = 4  (highest order + 1)
%        mode    = 5
%        stype   = 0
%        dtype   = 1
%        version = 1  (currently)
%           ==> nbr = 4511
%
%  It can thus be represented as:
%
%             G = [ 4511   0   0   0   0   0   0   0   0   0   0   0
%                     10  -1   0   0   0   0   0   0   1  -2  -3   0
%                      2   2   0   0   0   0   0   0   2   1   1   0
%                      5   0   0   0   7  10   0   0   1   0   0   0
%                      0   0   0   0   1   1   0   0   0   0   0   0
%                      1   0   0   0   1   0   0   0   1  -1   0   0
%                      3   3   0   0   0   0   0   0   2   2   0   0
%                      1   0   0   0   5 -10  -4   0   1   0   0   0
%                      3   3   0   0   3   1   2   0   0   0   0   0 ]
%
%  which, in fact, can be SQUEEZEd further into LOGCOL=3:
%
%             G = [ 3511   0   0   0   0   0   0   0   0
%                     10  -1   0   0   0   0   1  -2  -3
%                      2   2   0   0   0   0   2   1   1
%                      5   0   0   7  10   0   1   0   0
%                      0   0   0   1   1   0   0   0   0
%                      1   0   0   1   0   0   1  -1   0
%                      3   3   0   0   0   0   2   2   0
%                      1   0   0   5 -10  -4   1   0   0
%                      3   3   0   3   1   2   0   0   0 ]
%
return
