function [] = polpac_mode6()
%
%  Transfer function matrix (represented through trajectories):
%  ------------------------------------------------------------
%
%  Transfer function matrices are one way to describe linear systems in the
%  frequency domain.  POLPAC uses the same methodology as for polynomial
%  matrices to represent transfer function matrices.  Thereby, the
%  numerator polynomial matrix is simply concatenated from below by the
%  denominator polynomial matrix.  The same data structure can be used to
%  represent both continuous-time systems (G(s)) using the Laplace transform
%  (STYPE=0) and discrete-time systems (G(z)) using the z-transform (STYPE=1).
%
%  Storage mode 6 corresponds to storage mode 3.
%
%  Example:
%  --------
%
%  Given the transfer function matrix:
%
%                      (8z^2+5z+7)               (2z-5)
%             G(z) = [ -----------       0       ------
%                         z^3+1                   z^2
%
%                           1          5z-7
%                          ---       --------      1   ]
%                          z^3       (z^2-10)
%
%  spanned over the DOMAIN: [ 0 , 1 , 2 , 3 ]
%
%  We can evaluate these polynomials at the base values, and find:
%
%               z  |  P11(z)  P12(z)  P13(z)  P21(z)  P22(z)  P23(z)
%             -----+--------------------------------------------------
%               0  |    7       0      -5       1      -7       1
%               1  |   20       0      -3       1      -2       1
%               2  |   49       0      -1       1       3       1
%               3  |   94       0       1       1       8       1
%
%               z  |  Q11(z)  Q12(z)  Q13(z)  Q21(z)  Q22(z)  Q23(z)
%             -----+--------------------------------------------------
%               0  |    1       1       0       0     -10       1
%               1  |    2       1       1       1      -9       1
%               2  |    9       1       4       8      -6       1
%               3  |   28       1       9      27      -1       1
%
%  has:  logcol  = 4  (number of base values)
%        mode    = 6
%        stype   = 1
%        dtype   = 1
%        version = 1  (currently)
%           ==> nbr = 4641
%
%  It can thus be represented as:
%
%        P = [ 4641   0   0   0   0   0   0   0   0   0   0   0
%                 0   1   2   3   0   0   0   0   0   0   0   0
%                 7  20  49  94   0   0   0   0  -5  -3  -1   1
%                 1   1   1   1  -7  -2   3   8   1   1   1   1
%                 1   2   9  28   1   1   1   1   0   1   4   9
%                 0   1   8  27 -10  -9  -6  -1   1   1   1   1 ]
%
return
