function [] = polpac_mode8()
%
%  Polynomial matrix system description (represented through roots):
%  -----------------------------------------------------------------
%
%  One way to represent linear systems is through a polynomial matrix
%  representation:
%
%           P(s)*x(t) = Q(s)*u(t)
%                y(t) = R(s)*x(t) + W(s)*u(t)
%
%  in the continuous-time case (STYPE=0), or:
%
%           P(z)*x(t) = Q(z)*u(t)
%                y(t) = R(z)*x(t) + W(z)*u(t)
%
%  in the discrete-time case (STYPE=1).
%
%  u(t) is the input vector (of length m), y(t) is the output vector
%  (of length p), and x(t) is a partial state vector (of length q, where
%  q is between 1 and the system order n).
%
%  The four polynomial matrices:
%
%           P(s) :  dimension qxq
%           Q(s) :  dimension qxm
%           R(s) :  dimension pxq
%           W(s) :  dimension pxm
%
%  can conveniently be concatenated into a system polynomial matrix:
%
%           S(s) = [  P(s) , Q(s)
%                    -R(s) , W(s) ]
%
%  In POLPAC, we support this data structure which is augmented by a
%  top row that contains the necessary additional information making
%  this data structure recognizable as such:
%
%           S(s) = [  nbr , q , do_not_care
%                     P(s) , Q(s)
%                    -R(s) , W(s)           ]
%
%  The four polynomial matrices can be stored in any of the three basic
%  storage modes 1, 2, or 3.  Storage mode 8 corresponds to storage mode 2.
%
%  Notice the different sign of the R(s) polynomial matrix.  This
%  is useful since the zeros of this systems are the invariant dividers
%  of S(s) in this definition.
%
%  Example:
%  --------
%
%  Given the system:
%
%           (s + 1)*(s + 2)*x(t) = u(t)
%                           y(t) = 2*(s - 2.5)*x(t) + 20*u(t)
%
%  which describes a single-input/single-output system with:
%
%           P(s) = (s + 1)*(s + 2)
%           Q(s) = 1
%           R(s) = 2*(s - 2.5)
%           W(s) = 20
%
%  and thus:
%
%           S(s) = [ (s+1)(s+2)    1
%                    -2(s-2.5)    20 ]
%
%  with:    logcol  = 3  (highest order + 1)
%           mode    = 8
%           stype   = 0
%           dtype   = 2
%           version = 1  (currently)
%              ==>  nbr = 3821
%
%  can be represented as:
%
%           S = [ 3821   1   0   0   0   0
%                    1  -1  -2   1   0   0
%                    2   1   1   0   0   0
%                   -2 2.5   0  20   0   0
%                    1   1   0   0   0   0 ]
%
%  Notice that the partial state vector is of length q=1, while the
%  system order is n=2.
%
return
