function [] = polpac_mode9()
%
%  Polynomial matrix system description (represented through trajectories):
%  ------------------------------------------------------------------------
%
%  One way to represent linear systems is through a polynomial matrix
%  representation:
%
%           P(s)*x(t) = Q(s)*u(t)
%                y(t) = R(s)*x(t) + W(s)*u(t)
%
%  in the continuous-time case (STYPE=0), or:
%
%           P(z)*x(t) = Q(z)*u(t)
%                y(t) = R(z)*x(t) + W(z)*u(t)
%
%  in the discrete-time case (STYPE=1).
%
%  u(t) is the input vector (of length m), y(t) is the output vector
%  (of length p), and x(t) is a partial state vector (of length q, where
%  q is between 1 and the system order n).
%
%  The four polynomial matrices:
%
%           P(s) :  dimension qxq
%           Q(s) :  dimension qxm
%           R(s) :  dimension pxq
%           W(s) :  dimension pxm
%
%  can conveniently be concatenated into a system polynomial matrix:
%
%           S(s) = [  P(s) , Q(s)
%                    -R(s) , W(s) ]
%
%  In POLPAC, we support this data structure which is augmented by a
%  top row that contains the necessary additional information making
%  this data structure recognizable as such, and a second row containing
%  the DOMAIN information:
%
%           S(s) = [  nbr , q , do_not_care
%                     domain , do_not_care
%                     P(s) , Q(s)
%                    -R(s) , W(s)           ]
%
%  Storage mode 9 corresponds to storage mode 3.
%
%  Notice the different sign of the R(s) polynomial matrix.  This
%  is useful since the zeros of this systems are the invariant dividers
%  of S(s) in this definition.
%
%  Example:
%  --------
%
%  Given the system:
%
%           (s^2 + 3*s + 2)*x(t) = u(t)
%                           y(t) = (2*s - 5)*x(t) + 20*u(t)
%
%  which describes a single-input/single-output system with:
%
%           P(s) = s^2 + 3*s + 2
%           Q(s) = 1
%           R(s) = 2*s - 5
%           W(s) = 20
%
%  and thus:
%
%           S(s) = [ (s^2+3s+2)   1
%                      (-2s+5)   20 ]
%
%  This system can be represented e.g. over the domain [ 0 1 2 3 ]:
%
%             s  |  S11(s)  S12(s)  S21(s)  S22(s)
%           -----+----------------------------------
%             0  |    2       1       5      20
%             1  |    6       1       3      20
%             2  |   12       1       1      20
%             3  |   20       1      -1      20
%
%  with:    logcol  = 4  (number of base values)
%           mode    = 9
%           stype   = 0
%           dtype   = 1
%           version = 1  (currently)
%              ==>  nbr = 3911
%
%  can be represented as:
%
%           S = [ 3911   1   0   0   0   0   0   0
%                    0   1   2   3   0   0   0   0
%                    2   6  12  20   1   1   1   1
%                    5   3   1  -1  20  20  20  20 ]
%
%  Notice that the partial state vector is of length q=1, while the
%  system order is n=2.  Notice also that this system representation
%  obviously contains some redundancy, as the number of supporting
%  values is higher than would be required by the system order.
%
return
