function [] = polpac_polynomials()
%
%  POLPAC can represent polynomials in three different ways:
%
%
%  Coefficient representation of polynomials:
%  ------------------------------------------
%
%  Given a polynomial:  P(s) = a3*s^3 + a2*s^2 + a1*s + a0
%
%  POLPAC can represent this polynomial e.g. through its coefficients
%  (storage modes 1, 4, and 7).  Contrary to Matlab, POLPAC starts with
%  the LOWEST power in s, thus:
%
%             [ a0 , a1 , a2 , a3 ]
%
%  describes this polynomial which can represent one logical entry (one
%  logical element) in a polynomial matrix.
%
%
%  Root representation of polynomials:
%  -----------------------------------
%
%  Given a polynomial:  P(s) = k*(s-s1)^n1*(s-s2)^n2*(s-s3)^n3
%
%  POLPAC can represent this polynomial e.g. through its roots
%  (storage modes 2, 5, and 8).  Contrary to Matlab, POLPAC maintains
%  the knowledge about multiple roots, thus:
%
%             [ k , s1 , s2 , s3
%               n , n1 , n2 , n3 ]
%
%  describes this polynomial which can represent one logical entry (one
%  logical element) in a polynomial matrix (n = SUM(ni)).
%
%
%  Trajectory representation of polynomials:
%  -----------------------------------------
%
%  Given a polynomial:  P(s) = a3*s^3 + a2*s^2 + a1*s + a0
%
%  Such a polynomial can be represented by a base of s-values together
%  with their associated P(s) values:
%
%                  s  |  P(s)
%                -----+--------
%                  s1 |  P(s1)
%                  s2 |  P(s2)
%                  s3 |  P(s3)
%                 ... |  ...
%                  sk |  P(sk)
%
%  where all si-values and P(si)-values can be complex.  The set of selected
%  si-values is called the DOMAIN of the representation.  A DOMAIN together
%  with its associated P(si)-values is called a TRAJECTORY.
%
%  In order to completely determine the polynomial, we require at least
%  (n+1) supporting values, where n is the order of the polynomial.  If
%  more values are chosen, they are REDUNDANT.  This may help us with the
%  numerical behavior of operations based on this data representation.
%
%  A good choice might be to select the DOMAIN equidistantly spaced around
%  the unit circle, e.g.
%
%              DOMAIN = [ +1 , +j , -1 , -j ]
%
%  In POLPAC, we request that all TRAJECTORIES in a polynomial matrix are
%  spanned over the same DOMAIN.
%
return
