function [r,phi] = ppolar(x)
%
%  This function converts a complex matrix into two matrices
%  of same size, whereby the first output (r) denotes the length
%  of each matrix element, while the second denotes its phase
%  (in radian between 0 and 2*pi)
%
%  Input Parameter:
%  ----------------
%
%    x      := Any complex Matlab matrix
%
%  Output Parameters:
%  ------------------
%
%    r      := Matrix of lengths of x
%    phi    := Matrix of phases of x
%
push('POLAR')
%
r = abs(x);
re = real(x);
im = imag(x);
%
%  Loop is necessary to avoid division by zero
%  No vectorization possible
%
[n,m] = size(x);
for i=1:n,
  for k=1:m,
    if abs(re(i,k)) < 100*eps,
      if im(i,k) >= 0,
        phi(i,k) = pi/2;
        else
        phi(i,k) = 3*pi/2;
      end,
      else
      p = atan(im(i,k)/re(i,k));
      if re(i,k) > 0,
        if im(i,k) >= 0,
          phi(i,k) = p;
          else
          phi(i,k) = p + 2*pi;
        end,
        else
        phi(i,k) = p + pi;
      end,
    end,
  end,
end
%
pull
return
