function [q,r] = qrg(gm)
%
%  This function performs an upper triangularization of a rational function
%  matrix: GM = Q*R.
%
%  Input Parameter:
%  ----------------
%
%    gm     :=  The rational function matrix to be triangularized
%               (modes 4, 5, or 6 only)
%
%  Output Parameters:
%  ------------------
%
%    q      :=  A unimodular polynomial matrix
%    r      :=  An uppertriangular rational function matrix
%
push('QRG');
global debg
%
%  Start by unpacking the structural information.
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
[lrow,lcol] = logdim(gm);
dom = domain(gm);
%
%  Check for consistency.
%
if debg == 3,
  if mode < 4,
    disp('QRG: Error - Operates on modes 4 thru 6 only'),
    abort,
  end,
  if mode > 6,
    disp('QRG: Error - Operates on modes 4 thru 6 only'),
    abort,
  end,
end
%
%  Find the common denominator.
%
[pm,cdp] = commonden(gm);
%
%  Apply the QR decomposition to the polynomial matrix PM
%
[q,r] = qrp(pm);
%
%  Divide R by CDP.
%
cdp = multp(cdp,onesp(lrow,lcol,mode,logcol,stype,dom))
r = plm2tfm(r,cdp);
r = reduceg(r);
%
pull
return
