function [aadj] = radj(a)
%
%  Find the adjugate matrix of A.
%
%  Input Parameter:
%  ----------------
%
%    a      :=  Any square Matlab matrix
%
%  Output Parameter:
%  -----------------
%
%    aadj   :=  The adjugate matrix of A
%
push('RADJ');
global debg
%
errorbar = 100*eps;
[s1,s2] = size(a);
aadj = zeros(a);
%
%  Check out some error conditions
%
if debg == 3,
  if s1 ~= s2,
    disp('RADJ: Error - Works on square matrices only'),
    abort,
  end,
end
%
%  Handle the degenerate case
%
if s1 == 1,
  aadj = 1;
  pull,
  return,
end
%
%  Calculate the adjugate matrix now
%
for k=1:s1,
  for l=1:s1,
    sign = 1;
    kl = (k + l)/2;
    if abs(kl - round(kl + 0.25)) > errorbar,
      sign = -1;
    end,
    if k == 1,
      kk = 2:s1;
      else if k == s1,
        kk = 1:s1-1;
        else
        kk = [1:k-1,k+1:s1];
      end,
    end,
    if l == 1,
      ll = 2:s1;
      else if l == s1,
        ll = 1:s1-1;
        else
        ll = [1:l-1,l+1:s1];
      end,
    end,
    an = a(kk,ll);
    aadj(l,k) = sign*rdet(an);
  end,
end
%
pull
return
