function [detval] = rdetp(p1)
%
%  Find the determinant of a square POLPAC polynomial matrix in modes
%  1 thru 3.
%
%  Input Parameter:
%  ----------------
%
%    p1     :=  Any square POLPAC polynomial matrix in modes 1 thru 3
%
%  Output Parameter:
%  -----------------
%
%    detval :=  The determinant of the input polynomial matrix
%
push('RDETP');
global debg
%
[mod1,lcol1,dtyp1,styp1] = unpack(p1(1,1));
[s1,s2] = logdim(p1);
er = 100*eps;
%
%  Check out some error conditions
%
if debg == 3,
  if s1 ~= s2,
    disp('RDETP: Error - Works on square polpac structures only'),
    abort,
  end,
  if mod1 < 1,
    disp('RDETP: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
  if mod1 > 3,
    disp('RDETP: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
end
%
%  Create a zero POLPAC structure
%
dom = domain(p1);
zrop = zerop(1,1,mod1,lcol1,styp1,dom);
detval = zrop;
%
%  First extract a matrix A that has an element for each polynomial
%  in P1.  If the polynomial in P1(K,L) = 0, then A(K,L) = 0,
%  otherwise A(K,L) = 1
%
a = zeros(s1,s1);
xbase = [2 3 3];
xbase = xbase(mod1);
offset = [1 2 1];
offset = offset(mod1);
%
%  Create an A matrix for STRUCTM (helps RDETP1() to speed the
%  evaluation in many cases).  K, KK denote row indices, while
%  L, LL denote column indices.
%
for k=1:s1,
  for l=1:s1,
    kk = xbase + (k - 1)*offset;
    ll = (l - 1)*lcol1;
    for m=1:lcol1,
      if abs(p1(kk,ll+m)) > er,
        a(k,l) = 1;
      end,
    end,
    if mod1 == 2,
      if abs(p1(kk-1,ll+1)) > er,
        a(k,l) = 1;
      end,
    end,
  end,
end
%
if norm(a,'inf') < er,
  pull,
  return,
end
%
detval = rdetp1(p1,a,zrop,s1);
%
detval = squeeze(detval);
%
pull
return
