function [p2] = rts2cfs(p1)
%
%  This function converts a POLPAC data structure stored in storage modes
%  2, 5, or 8 into a data structure stored in the equivalent storage mode
%  1, 4, or 7.
%
%  Input Parameter:
%  ----------------
%
%    p1     :=  POLPAC data structure (mode = 2, 5, or 8)
%
%  Output Parameter:
%  -----------------
%
%    p2     :=  Equivalent POLPAC data structure (mode = 1, 4, or 7)
%
push('RTS2CFS')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(p1(1,1));
mcl = (mode + 1)/3;
%
%  Check for consistency
%
if debg == 3,
  if abs(round(mcl) - mcl) > 1000*eps,
    disp('RTS2CFS: Error - Input must be in factorized form'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 2,
  p2 = c21(p1);
  else if mode == 5,
    p2 = c54(p1);
    else
    p2 = c87(p1);
  end,
end
%
pull
return
