function [p2] = rts2trj(p1,dom)
%
%  This function converts a POLPAC data structure stored in storage modes
%  2, 5, or 8 into a data structure stored in the equivalent storage mode
%  3, 6, or 9.
%
%  Input Parameter:
%  ----------------
%
%    p1     :=  POLPAC data structure (mode = 2, 5, or 8)
%
%  Output Parameter:
%  -----------------
%
%    p2     :=  Equivalent POLPAC data structure (mode = 3, 6, or 9)
%
push('RTS2TRJ')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(p1(1,1));
mcl = (mode + 1)/3;
%
%  Check for consistency
%
if debg == 3,
  if abs(round(mcl) - mcl) > 1000*eps,
    disp('RTS2TRJ: Error - Input must be in factorized form'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 2,
  p2 = c23(p1,dom);
  else if mode == 5,
    p2 = c56(p1,dom);
    else
    p2 = c89(p1,dom);
  end,
end
%
pull
return
