function [pm2] = scm(pm1)
%
%   This function finds the smallest common multiple (SCM) PM2
%   of the polynomial matrix PM1.
%
%   Input:
%   ------
%     pm1    :=  polynomial matrix in mode 1, 2, or 3
%
%   Output:
%   -------
%     pm2    :=  SCM of polynomial matrix in mode 1, 2, or 3
%         
push('SCM');
global debg
%
%  First squeeze!
%
pm1 = squeeze(pm1);
%
%  Unpack the data structural information.
%
[mode,logcol,dtype,stype] = unpack(pm1(1,1));
[lrow,lcol] = logdim(pm1);
dom = domain(pm1);
%
%  Check for consistency.
%
if debg == 3,
  if mode < 1,
    disp('SCM: Error - Operates only on modes 1 thru 3'),
    mode,
    abort,
  end,
  if mode > 3,
    disp('SCM: Error - Operates only on modes 1 thru 3'),
    mode,
    abort,
  end,
end
%
%  If PM1 is a constant polynomial matrix, SCM is simply 1.
%
if mode ~= 3,
  if logcol == 1,
    pm2 = onesp(1,1,mode,logcol,stype,dom);
    pull,
    return,
  end,
end
if mode == 3,
  %
  %  A polynomial is constant if the evaluations over the
  %  base values are all the same.
  %
  cons = 1;
  for i=1:lrow,
    for k=1:lcol,
      k1 = (k - 1)*logcol + 1;
      k2 = k*logcol;
      pol1 = pm2(i+2,k1:k2);
      pol2 = pm2(i+2,k1)*ones(1,logcol);
      if norm(pol1 - pol2,'inf') > 1000*eps,
        cons = 0;
      end,
    end,
  end,
  if cons == 1,
    pm2 = onesp(1,1,mode,logcol,stype,dom);
    pull,
    return,
  end,
end
%
%  Loop over all polynomials.
% 
pm2 = onesp(1,1,mode,logcol,stype,dom);
for i=1:lrow,
  for k=1:lcol,
    pik = gget(pm1,i,k);
    pm2 = scm1(pm2,pik);
  end,
end
%
pull
return
