function [p3] = scm1(p1,p2)
%
%  This function operates on single polynomials stored in modes 1 thru 3.
%  P3 is the smallest common multiple of P1 and P2.
%
%  Mixed mode operations are handled with a preference of trajectories
%  over coefficients over roots.
%
%  Input Parameters:
%  -----------------
%
%    p1     :=  Single polynomial in modes 1 thru 3
%    p2     :=  Single polynomial in modes 1 thru 3
%
%  Output Parameter:
%  -----------------
%
%    p3     :=  Smallest common multiple of p1 and p2
%
push('SCM1')
global debg
%
%  Check for necessary conversions first
%
[p1,p2] = mixmod(p1,p2);
%
%  Start by unpacking the structural information
%
[mod1,lcol1,dtyp1,styp1] = unpack(p1(1,1));
[mod2,lcol2,dtyp2,styp2] = unpack(p2(1,1));
%
[n1,m1] = logdim(p1);
[n2,m2] = logdim(p2);
%
%  Check for consistency
%
if debg == 3,
  if mod1 < 1,
    disp('SCM1: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
  if mod1 > 3,
    disp('SCM1: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
  if styp2 ~= styp1,
    disp('SCM1: Error - Incompatible system types'),
    abort,
  end,
end
if debg >= 2,
  if n1*m1 ~= 1,
    disp('SCM1: Error - Operates on scalar polynomials only'),
    abort,
  end,
  if n2*m2 ~= 1,
    disp('SCM1: Error - Operates on scalar polynomials only'),
    abort,
  end,
end
%
[pr1,pr2,fac] = lcd1(p1,p2);
p3 = multp1(fac,multp1(pr1,pr2));
%
%  Normalize the gain factor to 1.
%
[mode,logcol,dtype,stype] = unpack(p3(1,1));
ggain = gain(p3);
if mode == 1,
  p3(2,1:logcol) = p3(2,1:logcol)/ggain;
  else if mode == 2,
    p3(2,1) = 1;
    else
    p3(3,1:logcol) = p3(3,1:logcol)/ggain;
  end,
end
%
pull
return
