function [] = show(pm,symb)
%
%  This function displays one POLPAC data structure to the user.
%  This is similar to the Matlab function DISPLAY.
%
%  Input Parameter:
%  ----------------
%
%    pm     : Any POLPAC data structure
%    symb   : Name of first input argument
%
push('SHOW')
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
%
%  Group according to the mode
%
%  Mode = 0
%
if mode == 0,
  [a,b,c,d] = oldsyst(pm);
  t1 = 'State Coupling Matrix:';
  t2 = '----------------------';
  txt = [ t1 ; t2 ];
  disp(txt),
  a,
  t1 = 'Input Coupling Matrix:';
  t2 = '----------------------';
  txt = [ t1 ; t2 ];
  disp(txt),
  b,
  t1 = 'Output Coupling Matrix:';
  t2 = '-----------------------';
  txt = [ t1 ; t2 ];
  disp(txt),
  c,
  t1 = 'Input/Output Coupling Matrix:';
  t2 = '-----------------------------';
  txt = [ t1 ; t2 ];
  disp(txt),
  d,
  pull,
  return,
end
%
%  Mode = 3, 6, or 9
%
m3 = mode/3;
if abs(m3 - round(m3)) < 100*eps,
  disp('SHOW: Warning - Function not yet implemented'),
  pull,
  return,
end
%
%  Decide on print symbol
%
s = 's';
if stype == 1,
  s = 'z';
end
%
%  Modes = 1 .. 6
%
if nargin == 1,
  symb = 'P';
end
if mode > 3,
  if nargin == 1,
    symb = 'G';
  end,
end
if mode < 7,
  show1(pm,symb);
  pull,
  return,
end
%
%  Modes 7 .. 9
%  Extract the four polynomial matrices, and handle each separately.
%
[p,q,r,w] = pms2plm(pm);
t1 = 'Partial State Coupling Matrix:';
t2 = '------------------------------';
txt = [ t1 ; t2 ];
disp(txt)
show1(p,'P')
t1 = 'Input Coupling Matrix:';
t2 = '----------------------';
txt = [ t1 ; t2 ];
disp(txt)
show1(q,'Q')
t1 = 'Output Coupling Matrix:';
t2 = '-----------------------';
txt = [ t1 ; t2 ];
disp(txt)
show1(r,'R')
t1 = 'Input/Output Coupling Matrix:';
t2 = '-----------------------------';
txt = [ t1 ; t2 ];
disp(txt)
show1(w,'W')
%
pull
return
