function [] = show1(pm,symb)
%
%  This function displays one POLPAC data structure stored
%  in modes 1 thru 6 to the user.  This is similar to the Matlab
%  function DISP.
%
%  Input Parameter:
%  ----------------
%
%    pm     : Any POLPAC data structure (modes 1 thru 6)
%    symb   : Print symbol (name of data structure)
%
push('SHOW1')
global debg
global warn
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(pm(1,1));
%
%  Check for compatibility
%
if debg == 3,
  if mode == 0,
    disp('SHOW1: Error - Operates only on modes 1 thru 6'),
    mode,
    abort,
  end,
  if mode > 6,
    disp('SHOW1: Error - Operates only on modes 1 thru 6'),
    mode,
    abort,
  end,
end
%
%  Decide on print symbol
%
s = 's';
if stype == 1,
  s = 'z';
end
%
%  Convert data structure into text string
%
if mode < 4,
  [txt,indx] = strp(pm);
end
if mode > 3,
  [txt,indx] = strg(pm);
end
%
%  Print header
%
t = [ symb , '(' , s , ') =' ];
disp(t)
%
%  if less than one page, simply display now.
%
[n,m] = size(indx);
if indx(m) < 80,
  disp(txt);
  else
  %
  %  Nope!  I thought so.
  %  Check whether any column is broader than one page.
  %  if so, issue a warning message.
  %
  iindx = [ 0 , indx(1:m-1) ];
  dff = indx - iindx;
  if max(dff) > 79,
    if warn == 1,
      disp('SHOW1: Warning - Column too broad. Cannot properly display'),
    end,
  end,
  %
  %  Write the column number on top of text
  %
  txt = [ ' '*ones(2,indx(m)) ; txt ];
  for i=1:m,
    i1 = iindx(i) + round(dff(i)/2) - 4;
    i1 = max([i1,1]);
    i2 = i1 + 6;
    t = strc(i);
    if i < 10,
      txt(1,i1:i2) = [ 'Col.  ' , t(1,1) ];
      else if i < 100,
        txt(1,i1:i2) = [ 'Col. ' , t(1,1:2) ];
        else if i < 1000,
          txt(1,i1:i2) = [ 'Col.' , t(1,1:3) ];
        end,
      end,
    end,
  end,
  %
  %  Split text vertically into pages
  %  and display it.
  %
  i1 = 1;
  for i=2:m,
    if indx(i) - i1 > 78,
      i2 = iindx(i);
      t = txt(:,i1:i2);
      disp(t),
      disp(' '),
      i1 = i2 + 1;
    end,
  end,
  if i1 < indx(m),
    i2 = indx(m);
    t = txt(:,i1:i2);
    disp(t),
    disp(' '),
  end,
end
%
pull
return
