function [vec2,indx] = sortc(vec1)
%
%  This function sorts complex column vectors according to their
%  magnitudes and phases.
%
%  They are first sorted along their increasing magnitudes, and,
%  in case of equality there, they are sorted along their phase, an
%  angle between 0 and 2*pi rad.
%
%  Input Parameters:
%  -----------------
%
%    vec1   := A column vector of complex numbers
%
%  Output Parameters:
%  ------------------
%
%    indx   := A vector of the sorted indices for vec1.
%    vec2   := A vector with the same elements as in vec1, but sorted.
%
push('SORTC')
global debg
%
[n,m] = size(vec1);
%
%  Check for consistency
%
if debg == 3,
  if m ~= 1,
    disp('SORTC: Error - The input must be a column vector'),
    abort,
  end,
end
%
%  Transform into polar coordinates, and sort according to length
%
ll1 = vec1;
[length,phase] = ppolar(ll1);
[length,indx] = sort(length);
ll1 = ll1(indx);
phase = phase(indx);
%
%  Check for roots with same length, and sort them according
%  to phase.
%
k = 1;
l2 = 0;
index = 0;
for i=2:n,
  if abs(length(i) - length(k)) > 1000*eps,
    ik = i - k;
    if ik > 1,
      sll1 = ll1(k:i-1);
      sphase = phase(k:i-1);
      [sphase,indx2] = sort(sphase);
      sll1 = sll1(indx2);
      indxx= indx(k:i-1);
      indx2=indxx(indx2);
      else
      indx2= indx(k);
      sll1 = ll1(k);
    end,
    index = [index;indx2];
    l2 = [ l2 ; sll1 ];
    k = i;
  end,
end
%
sll1 = ll1(k:n);
sphase = phase(k:n);
if n > k,
  [sphase,indx2] = sort(sphase);
  sll1 = sll1(indx2);
  indxx= indx(k:n);
  indx2=indxx(indx2);
  else
  indx2=indx(n);
  sll1 = ll1(n);
end
l2 = [ l2 ; sll1 ];
index = [index;indx2];
indx = index(2:n+1);
vec2 = l2(2:n+1);
%
pull
return
