function [pms] = ss2pms(s,m,dom)
%
%  This function converts a state-space description (stored in
%  storage mode 0) into a polynomial matrix system description
%  (stored in storage mode 7 thru 9).
%
%  Input Parameters:
%  -----------------
%
%    s      :=  System in state-space description (input mode = 0)
%    m      :=  Desired output mode (must be 7 thru 9)
%    dom    :=  Desired domain (only needed if m = 9)
%
%  Output Parameter:
%  -----------------
%
%    pms    :=  Polynomial matrix system description (output mode = 7 thru 9)
%
push('SS2PMS')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(s(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode ~= 0,
    disp('SS2PMS: Error - Input must be in mode 0'),
    abort,
  end,
  if m < 6,
    disp('SS2PMS: Error - Desired output mode must be 7 thru 9'),
    abort,
  end,
end
%
%  Do the conversion now
%
if m == 7,
  pms = c07(s);
  else if m == 8,
    pms = c08(s);
    else
    pms = c09(s,dom);
  end,
end
%
pull
return
