function [gm] = ss2tfm(s,m,dom)
%
%  This function converts a state-space description (stored in
%  storage mode 0) into a transfer function matrix (stored in
%  storage mode 4 thru 6).
%
%  Input Parameters:
%  -----------------
%
%    s      :=  System in state-space description (input mode = 0)
%    m      :=  Desired output mode (must be 4 thru 6)
%    dom    :=  Desired domain (only needed if m = 6)
%
%  Output Parameter:
%  -----------------
%
%    gm     :=  Transfer function matrix (output mode = 4 thru 6)
%
push('SS2TFM')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(s(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode ~= 0,
    disp('SS2TFM: Error - Input must be in mode 0'),
    abort,
  end,
  if m < 3,
    disp('SS2TFM: Error - Desired output mode must be 4 thru 6'),
    abort,
  end,
  if m > 6,
    disp('SS2TFM: Error - Desired output mode must be 4 thru 6'),
    abort,
  end,
end
%
%  Do the conversion now
%
if m == 4,
  gm = c04(s);
  else if m == 5,
    gm = c05(s);
    else
    gm = c06(s,dom);
  end,
end
%
pull
return
