function [tt] = strc(nmbr)
%
%  This function converts a possibly complex number into a text string
%  It calls the Matlab function STR.
%
%  Input Parameter:
%  ----------------
%
%    nmbr   := A Matlab number (integer, real, or complex)
%
%  Output Parameter:
%  -----------------
%
%    tt     := Text string with number encoded
%
push('STRC')
global debg
%
%  if debg=3, check for consistency.  nmbr must be scalar.
%
if debg == 3,
  [n,m] = size(nmbr);
  if n*m ~= 1,
    disp('STRC: Error - Input must be a scalar number');
    nmbr,
    abort,
  end,
end
%
%  Treat real part and imaginary part separately
%
rnbr = real(nmbr);
inbr = imag(nmbr);
%
%  Special case: rnbr=0
%
if rnbr == 0,
  tt = '0';
  if inbr == 0, pull, return, end,
end
%
%  General case: rnbr~=0
%
if rnbr ~= 0,
  dtype = 2;
  if abs(rnbr - round(rnbr)) < 100*eps, dtype = 1; end,
  tt = num2str(rnbr);
  tt = truncate(tt,dtype);
end
%
%  Complex cases
%
if inbr == 0, pull, return, end
%
dtype = 2;
if abs(inbr - round(inbr)) < 100*eps, dtype = 1; end,
t = num2str(inbr);
t = truncate(t,dtype);
%
%  Imaginary case
%
if rnbr == 0,
  tt = [ t , 'i' ];
  pull,
  return,
end
%
%  General complex case
%
tt = [ '(' , tt , ' + ' , t , 'i)' ];
%
pull
return
