function [tt] = strg1(g)
%
%  This function transforms a POLPAC transfer function (modes 4 thru 6) into
%  a string representation for later display.
%
%  Input Parameter:
%  ----------------
%
%    g      := POLPAC single transfer function (modes 4 thru 6)
%
%  Output Parameter:
%  -----------------
%
%    tt     := Text string with transfer function encoded
%
push('STRG1')
global debg
%
%  Start by unpacking the storage information
%
[mode,logcol,dtype,stype] = unpack(g(1,1));
%
%  if debg=3, check for consistency.
%
if debg == 3,
  [n,m] = logdim(g);
  if n*m ~= 1,
    disp('STRG1: Error - Operates only on scalar transfer functions'),
    abort,
  end,
  if mode < 4,
    disp('STRG1: Error - Operates on modes 4 thru 6 only'),
    mode,
    abort,
  end,
  if mode > 6,
    disp('STRG1: Error - Operates on modes 4 thru 6 only'),
    mode,
    abort,
  end,
end
%
%  Set the display symbol to either 's' or 'z'
%
s = 's';
if stype == 1,
  s = 'z';
end
%
%  Decompose into numerator and denominator
%
[p1,p2] = tfm2plm(g);
%
%  Treat first the case mode=6
%
if mode == 6,
  disp('STRG1: Error - Sorry, feature not yet implemented');
  abort,
end
%
%  Now, treat modes 4 and 5
%
%  Transform the two polynomials into text strings
%
t1 = strp1(p1);
t2 = strp1(p2);
%
%  Center the smaller of the two, and compose
%  the final text string
%
[n1,m1] = size(t1);
[n2,m2] = size(t2);
if m1 == m2,
  tt = [ t1 ; '-'*ones(1,m1) ; t2 ];
end
if m1 > m2,
  dff = m1 - m2;
  bpad = round(dff/2);
  epad = dff - bpad;
  t2 = [ ' '*ones(1,bpad) , t2 , ' '*ones(1,epad) ];
  tt = [ t1 ; '-'*ones(1,m1) ; t2 ];
end
if m1 < m2,
  dff = m2 - m1;
  bpad = round(dff/2);
  epad = dff - bpad;
  t1 = [ ' '*ones(1,bpad) , t1 , ' '*ones(1,epad) ];
  tt = [ t1 ; '-'*ones(1,m2) ; t2 ];
end
%
pull
return
