function [tt] = strp1(p)
%
%  This function transforms a POLPAC polynomial (modes 1 thru 3) into
%  a string representation.
%
%  Input Parameter:
%  ----------------
%
%    p      := POLPAC single polynomial (modes 1 thru 3)
%
%  Output Parameter:
%  -----------------
%
%    tt     := Text string with polynomial encoded
%
push('STRP1')
global debg
%
%  First squeeze!
%
p = squeeze(p);
%
%  Start by unpacking the storage information
%
[mode,logcol,dtype,stype] = unpack(p(1,1));
%
%  if debg=3, check for consistency.
%
if debg == 3,
  [n,m] = logdim(p);
  if n*m ~= 1,
    disp('STRP1: Error - Operates only on scalar polynomials'),
    abort,
  end,
  if mode < 1,
    disp('STRP1: Error - Operates on modes 1 thru 3 only'),
    mode,
    abort,
  end,
  if mode > 3,
    disp('STRP1: Error - Operates on modes 1 thru 3 only'),
    mode,
    abort,
  end,
end
%
%  Set the display symbol to either 's' or 'z'
%
s = 's';
if stype == 1,
  s = 'z';
end
%
%  Treat each mode separately.  Start with mode=1
%
tt = '(';
if mode == 1,
  for l=logcol:-1:1,
    ord = strc(l - 1);
    p2l = p(2,l);
    if p2l >= 0,
      sgn = 1;
      t = strc(p2l);
    end,
    if p2l < 0,
      sgn = -1;
      t = strc(-p2l);
    end,
    p2l = abs(p2l);
    if p2l < 1000*eps,
      if logcol == 1,
        tt = [ tt , t ];
      end,
    end,
    if p2l > 1000*eps,
      if l == logcol,
        if sgn < 0,
          tt = [ tt , '-' ];
        end,
      end,
      if l < logcol,
        if sgn > 0,
          tt = [ tt , ' + ' ];
        end,
        if sgn < 0,
          tt = [ tt , ' - ' ];
        end,
      end,
      p2l1 = abs(p2l - 1);
      if p2l1 > 1000*eps,
        if l > 2,
          tt = [ tt , t , '*' , s , '^' , ord ];
        end,
        if l == 2,
          tt = [ tt , t , '*' , s ];
        end,
        if l == 1,
          tt = [ tt , t ];
        end,
      end,
      if p2l1 < 1000*eps,
        if l > 2,
          tt = [ tt , s , '^' , ord ];
        end,
        if l == 2,
          tt = [ tt , s ];
        end,
        if l == 1,
          tt = [ tt , t ];
        end,
      end,
    end,
  end,
  tt = [ tt , ')' ];
end
%
%  Treat now the case mode=2
%
if mode == 2,
  t = strc(p(2,1));
  p21 = abs(p(2,1));
  gain = 0;
  if abs(p21 - 1) > 1000*eps,
    gain = 1;
    tt = [ tt , t ];
  end,
  if abs(p21 - 1) < 1000*eps,
    if p(3,1) == 0,
      gain = 1;
      tt = [ tt , t ];
      else if p(2,1) < 0,
        tt = [ tt , '-' ];
      end,
    end,
  end,
  if logcol > 1,
    for l=2:logcol,
      if gain == 1,
        tt = [ tt , '*' ];
      end,
      if gain == 0,
        gain = 1;
      end,
      if p(2,l) == 0,
        tt = [ tt , s ];
      end,
      p2l = p(2,l);
      if p2l > 0,
        t = strc(p2l);
        tt = [ tt , '(' , s , ' - ', t , ')' ];
      end,
      if p2l < 0,
        t = strc(-p2l);
        tt = [ tt , '(' , s , ' + ' t , ')' ];
      end,
      if p(3,l) > 1,
        ord = strc(p(3,l));
        tt = [ tt , '^' , ord ];
      end,
    end,
  end,
  tt = [ tt , ')' ];
end
%
%  Treat now the case mode=3
%
if mode == 3,
  disp('STRP1: Error - Sorry, feature not yet implemented')
  abort,
end
%
pull
return
