function [tp,tq,tr,tw,indx] = strs(sm)
%
%  This function maps the system matrix SM (in storage modes 7 thru 9)
%  into four text strings for display.
%
%  Input Parameter:
%  ----------------
%
%    sm     := POLPAC system matrix (modes 7 thru 9)
%
%  Output Parameters:
%  ------------------
%
%    tp     := Text string with P(s) encoded
%    tq     := Text string with Q(s) encoded
%    tr     := Text string with R(s) encoded
%    tw     := Text string with W(s) encoded
%    indx   := index matrix containing the column number of TXT where
%              each logical field ends.  Dim(indx) = 4xq, where q
%              denotes the largest number of logical columns of the
%              four polynomial matrices.  Each row contains the indices
%              for one of the polynomial matrices.
%
push('STRS')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(sm(1,1));
[ns,ms] = size(sm);
if ms == 1,
  n = 0;
  else
  n = sm(1,2);
end
[p,m] = logdim(sm);
%
%  Check for consistency
%
if debg == 3,
  if mode < 7,
    disp('STRS: Error - Operates on modes 7 thru 9 only');
    mode,
    abort,
  end,
  if mode > 9,
    disp('STRS: Error - Operates on modes 7 thru 9 only');
    mode,
    abort,
  end,
end
%
%  Start by unpacking the four system matrices.
%
[pm,qm,rm,wm] = pms2plm(sm);
%
%  Treat first the case: mode=9
%
if mode == 9,
  disp('STRS: Error - This function is not yet implemented');
  abort,
end
%
%  The mode is secured to be either 7 or 8.
%
%  Transform each of the four polynomial matrices into text strings
%
if n > 0,
  [tp,ip] = strp(pm);
  [tq,iq] = strp(qm);
  [tr,ir] = strp(rm);
end
[tw,iw] = strp(wm);
%
%  Concatenate the four index vectors into one index matrix
%
if n > 0,
  [np,mp] = size(ip);
  [nq,mq] = size(iq);
  [nr,mr] = size(ir);
  else
  mp = 0;
  mq = 0;
  mr = 0;
end
[nw,mw] = size(iw);
mm = max([mp,mq,mr,mw]);
indx = zeros(4,mm);
if n > 0,
  indx(1,1:mp) = ip;
  indx(2,1:mq) = iq;
  indx(3,1:mr) = ir;
end
indx(4,1:mw) = iw;
%
pull
return
