function [u,s,v] = svdg(gm)
%
%  This function performs a Smith MacMillan diagonalization of a rational
%  function matrix: GM = U*S*V'.
%
%  Input Parameter:
%  ----------------
%
%    gm     :=  The rational function matrix to be diagonalized
%               (modes 4, 5, or 6 only)
%
%  Output Parameters:
%  ------------------
%
%    u      :=  A unimodular polynomial matrix
%    s      :=  A diagonal rational function matrix
%    v      :=  A unimodular polynomial matrix
%
push('SVDG');
global debg
%
%  Start by unpacking the structural information.
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
[lrow,lcol] = logdim(gm);
dom = domain(gm);
%
%  Check for consistency.
%
if debg == 3,
  if mode < 4,
    disp('SVDG: Error - Operates on modes 4 thru 6 only'),
    abort,
  end,
  if mode > 6,
    disp('SVDG: Error - Operates on modes 4 thru 6 only'),
    abort,
  end,
end
%
%  Find the common denominator.
%
[pm,cdp] = commonden(gm);
%
%  Apply the SVD decomposition to the polynomial matrix PM
%
[u,s,v] = svdp(pm);
%
%  Divide S by CDP.
%
cdp = multp(cdp,onesp(lrow,lcol,mode-3,logcol,stype,dom));
s = plm2tfm(s,cdp);
s = reduceg(s);
%
pull
return
