function [pm,qm] = tfm2plm(gm)
%
%  This function converts a single transfer function matrix
%  (stored in storage mode 4 thru 6) into two polynomial matrices
%  (stored in the corresponding storage modes 1 thru 3).
%
%  Input Parameters:
%  -----------------
%
%    gm     := Transfer function matrix (mode = 4 thru 6)
%
%  Output Parameter:
%  -----------------
%
%    pm     := Numerator polynomial matrix (mode = 1 thru 3)
%    qm     := Denominator polynomial matrix (mode = 1 thru 3)
%
push('TFM2PLM')
global debg
%
%  Start by unpacking the structural information
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode < 4,
    disp('TFM2PLM: Error - Input must be transfer function matrix'),
    abort,
  end,
  if mode > 6,
    disp('TFM2PLM: Error - Input must be transfer function matrix'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 4,
  [pm,qm] = c41(gm);
  else if mode == 5,
    [pm,qm] = c52(gm);
    else
    [pm,qm] = c63(gm);
  end,
end
%
pull
return
