function [pms] = tfm2pms(gm)
%
%  This function converts a transfer function matrix (stored in
%  storage modes 4 thru 6) into a polynomial matrix system
%  description (stored in the corresponding modes 7 thru 9).
%
%  Input Parameter:
%  ----------------
%
%    gm     :=  Transfer function matrix (mode = 4 thru 6)
%
%  Output Parameter:
%  -----------------
%
%    pms    :=  Polynomial matrix system description (mode = 7 thru 9)
%
push('TFM2PMS')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode < 4,
    disp('TFM2PMS: Error - Input must be a transfer function matrix'),
    abort,
  end,
  if mode > 6,
    disp('TFM2PMS: Error - Input must be a transfer function matrix'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 4,
  pms = c47(gm);
  else if mode == 5,
    pms = c58(gm);
    else
    pms = c69(gm);
  end,
end
%
pull
return
