function [s] = tfm2ss(gm)
%
%  This function converts a transfer function matrix (stored in
%  storage modes 4 thru 6) into a state-space description (stored in
%  storage mode 0).
%
%  Input Parameter:
%  ----------------
%
%    gm     :=  Transfer function matrix (mode = 4 thru 6)
%
%  Output Parameter:
%  -----------------
%
%    s      :=  State-space description (mode = 0)
%
push('TFM2SS')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(gm(1,1));
%
%  Check for consistency
%
if debg == 3,
  if mode < 4,
    disp('TFM2SS: Error - Input must be a transfer function matrix'),
    abort,
  end,
  if mode > 6,
    disp('TFM2SS: Error - Input must be a transfer function matrix'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 4,
  s = c40(gm);
  else if mode == 5,
    s = c50(gm);
    else
    s = c60(gm);
  end,
end
%
pull
return
