function [trgm] = traceg(g1)
%
%  Find the trace of a POLPAC rational function matrix.
%
%  Input Parameter:
%  ----------------
%
%    g1     :=  Any square POLPAC data structure in modes 4 thru 6.
%
%  Output Parameter:
%  -----------------
%
%    trgm   :=  The TRACE of the square rational function matrix, i.e.,
%               the sum of the diagonal rational functions.
%
push('TRG');
global debg
%
[mod1,lcol1,dtyp1,styp1] = unpack(g1(1,1));
[s1,s2] = logdim(g1);
%
%  Check out some error conditions
%
if debg == 3,
  if s1 ~= s2,
    disp('TRG: Error - Works on square polpac structures only'),
    abort,
  end,
  if mod1 < 4,
    disp('TRG: Error - Operates only on modes 4 thru 6'),
    mod1,
    abort,
  end,
  if mod1 > 6,
    disp('TRG: Error - Operates only on modes 4 thru 6'),
    mod1,
    abort,
  end,
end
%
%  Do it!
%
trgm = gget(g1,1,1);
if s1 > 1,
  for k=2:s1,
    g2 = gget(g1,k,k);
    trgm = addg1(trgm,g2);
  end,
end
%
trgm = squeeze(trgm);
%
pull
return
