function [trpm] = tracep(p1)
%
%  Find the trace of a POLPAC polynomial matrix.
%
%  Input Parameter:
%  ----------------
%
%    p1     :=  Any square POLPAC data structure in modes 1 thru 3.
%
%  Output Parameter:
%  -----------------
%
%    trpm   :=  The TRACE of the square polynomial matrix, i.e.,
%               the sum of the diagonal polynomials.
%
push('TRP');
global debg
%
[mod1,lcol1,dtyp1,styp1] = unpack(p1(1,1));
[s1,s2] = logdim(p1);
%
%  Check out some error conditions
%
if debg == 3,
  if s1 ~= s2,
    disp('TRP: Error - Works on square polpac structures only'),
    abort,
  end,
  if mod1 < 1,
    disp('TRP: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
  if mod1 > 3,
    disp('TRP: Error - Operates only on modes 1 thru 3'),
    mod1,
    abort,
  end,
end
%
%  Do it!
%
trpm = gget(p1,1,1);
if s1 > 1,
  for k=2:s1,
    p2 = gget(p1,k,k);
    trpm = addp1(trpm,p2);
  end,
end
%
trpm = squeeze(trpm);
%
pull
return
