function [p2] = trj2cfs(p1)
%
%  This function converts a POLPAC data structure stored in storage modes
%  3, 6, or 9 into a data structure stored in the equivalent storage mode
%  1, 4, or 7.
%
%  Input Parameter:
%  ----------------
%
%    p1     :=  POLPAC data structure (mode = 3, 6, or 9)
%
%  Output Parameter:
%  -----------------
%
%    p2     :=  Equivalent POLPAC data structure (mode = 1, 4, or 7)
%
push('TRJ2CFS')
global debg
%
%  Unpack the structural information
%
[mode,logcol,dtype,stype] = unpack(p1(1,1));
mcl = mode/3;
%
%  Check for consistency
%
if debg == 3,
  if abs(round(mcl) - mcl) > 1000*eps,
    disp('TRJ2CFS: Error - Input must be in trajectory form'),
    abort,
  end,
  if mode == 0,
    disp('TRJ2CFS: Error - Input must be in trajectory form'),
    abort,
  end,
end
%
%  Do the conversion now
%
if mode == 9,
  p2 = c31(p1);
  else if mode == 6,
    p2 = c64(p1);
    else
    p2 = c97(p1);
  end,
end
%
pull
return
