function [mode,logcol,dtype,stype] = unpack(nbr)
%
%  This function UNPACKs a number of data structure information items
%  from an integer number.
%
%  Input Parameters:
%  -----------------
%
%    nbr    ::= coded integer (for details, cf. function pack)
%
%  Output Parameters:
%  ------------------
%    mode   ::= storage mode of the data structure (cf. function pack)
%    logcol ::= number of physical columns per logical column
%    dtype  ::= data type (cf. function pack)
%    stype  ::= system type (cf. function pack)
%    
push('UNPACK')
global debg
%
%  if debg=3, check for consistency
%
if debg == 3,
  if abs(nbr-round(nbr)) > 10*eps,
    disp('UNPACK: Error - nbr must be integer'),
    nbr,
    abort,
  end,
end
%
%  Unpack the data now.
%
version = round(nbr - 10*round(nbr/10 - 0.5 + 10*eps));
logcol = round(nbr/1000 - 0.5 + 10*eps);
nbr2 = nbr - 1000*logcol;
mode = round(nbr2/100 - 0.5 + 10*eps);
nbr2 = nbr2 - 100*mode;
typ = round(nbr2/10 - 0.5 + 10*eps);
stype = round((typ - 2)/3);
dtype = typ - 3*stype;
%
%  if debg=3, check for consistency
%
if debg == 3,
  if version ~= 1,
    disp('UNPACK: Error - version must be 1.0'),
    version,
    abort,
  end,
  if logcol < 1,
    disp('UNPACK: Error - logcol must be a positive integer'),
    logcol,
    abort,
  end,
  if mode < 0,
    disp('UNPACK: Error - mode may not be negative'),
    mode,
    abort,
  end,
  if mode > 9,
    disp('UNPACK: Error - mode must be smaller than 10'),
    mode,
    abort,
  end,
  if dtype < 1,
    disp('UNPACK: Error - dtype must be a positive integer'),
    dtype,
    abort,
  end,
  if dtype > 3,
    disp('UNPACK: Error - dtype must be smaller than 4'),
    dtype,
    abort,
  end,
  if stype < 0,
    disp('UNPACK: Error - stype must not be negative'),
    stype,
    abort,
  end,
  if stype > 1,
    disp('UNPACK: Error - stype must be smaller than 2'),
    stype,
    abort,
  end,
end
%
pull
return
