function [vndr] = vdm(v,mcol)
%
%  This function returns a Van-der-Monde matrix over the
%  values of the elements of row vector v.
%
%  Input Parameters:
%  -----------------
%
%    v      := Row vector of any data type
%    mcol   := Non-negative integer signifying column length of
%              Van-der-Monde matrix to be returned
%
%          mcol = 0: column length equal to logcol of input matrix
%          mcol > 0: column length equal to mcol (mcol cannot be
%                    greater than logcol of input matrix)
%
%
%  Output Parameters:
%  ------------------
%
%    vndr  := Van-der-Monde matrix over elements of v
%
push('VDM')
global debg
%
[r,c] = size(v);
%
%  Check for consistency
%
if debg == 3,
  if r ~= 1,
    disp('VDM: Error - Operates on row vectors only'),
    abort,
  end,
end
%
%  Create shell to receive column vectors; for non-zero
%  mcol, make dimensions logcol_of_p1 X mcol
%
c1 = c;
if mcol > 0,
  c1 = mcol;
end
%
vndr = ones(c,c1);
%
%  Create column vectors as powers of elements of v
%  and insert into ONES matrix at appropriate column position
%
vv = conj(v');
for i = 2:c1,
  vndr(:,i) = vndr(:,(i-1)) .* vv;
end
%
pull
return
